package com.tzld.longarticle.recommend.server.service.recommend;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ctrip.framework.apollo.spring.annotation.ApolloJsonValue;
import com.google.common.collect.Lists;
import com.tzld.longarticle.recommend.server.common.enums.StatusEnum;
import com.tzld.longarticle.recommend.server.common.enums.aigc.ChannelEnum;
import com.tzld.longarticle.recommend.server.common.enums.aigc.ProduceContentAuditStatusEnum;
import com.tzld.longarticle.recommend.server.common.enums.aigc.PublishPlanInputSourceTypesEnum;
import com.tzld.longarticle.recommend.server.common.enums.longArticle.ArticleVideoAuditStatusEnum;
import com.tzld.longarticle.recommend.server.common.enums.longArticle.ArticleVideoBadStatusEnum;
import com.tzld.longarticle.recommend.server.common.enums.longArticle.VideoPoolPlatformEnum;
import com.tzld.longarticle.recommend.server.common.enums.recommend.AccountBusinessTypeEnum;
import com.tzld.longarticle.recommend.server.common.enums.recommend.ArticleTypeEnum;
import com.tzld.longarticle.recommend.server.common.enums.recommend.ContentPoolEnum;
import com.tzld.longarticle.recommend.server.common.enums.recommend.RankStrategyEnum;
import com.tzld.longarticle.recommend.server.mapper.aigc.AigcBaseMapper;
import com.tzld.longarticle.recommend.server.mapper.aigc.PublishContentMapper;
import com.tzld.longarticle.recommend.server.mapper.crawler.CrawlerBaseMapper;
import com.tzld.longarticle.recommend.server.mapper.longArticle.LongArticleBaseMapper;
import com.tzld.longarticle.recommend.server.model.dto.ContentPoolTypeDTO;
import com.tzld.longarticle.recommend.server.model.dto.ProduceContentDTO;
import com.tzld.longarticle.recommend.server.model.dto.ProducePlanAuditCheckDTO;
import com.tzld.longarticle.recommend.server.model.dto.PublishContentDTO;
import com.tzld.longarticle.recommend.server.model.dto.aigc.IdChannelDTO;
import com.tzld.longarticle.recommend.server.model.dto.aigc.IdPlatformDTO;
import com.tzld.longarticle.recommend.server.model.entity.aigc.*;
import com.tzld.longarticle.recommend.server.model.entity.crawler.AccountAvgInfo;
import com.tzld.longarticle.recommend.server.model.entity.crawler.Article;
import com.tzld.longarticle.recommend.server.model.entity.crawler.ArticleDetailInfo;
import com.tzld.longarticle.recommend.server.model.entity.crawler.PublishSortLog;
import com.tzld.longarticle.recommend.server.model.entity.longArticle.*;
import com.tzld.longarticle.recommend.server.model.param.MiniprogramTaskParam;
import com.tzld.longarticle.recommend.server.model.param.PublishContentParam;
import com.tzld.longarticle.recommend.server.model.vo.*;
import com.tzld.longarticle.recommend.server.model.vo.aigc.ProduceAuditLayoutContentObjVO;
import com.tzld.longarticle.recommend.server.repository.aigc.*;
import com.tzld.longarticle.recommend.server.repository.crawler.AccountAvgInfoRepository;
import com.tzld.longarticle.recommend.server.repository.crawler.ArticleDetailInfoRepository;
import com.tzld.longarticle.recommend.server.repository.crawler.ArticleRepository;
import com.tzld.longarticle.recommend.server.repository.crawler.PublishSortLogRepository;
import com.tzld.longarticle.recommend.server.repository.longArticle.*;
import com.tzld.longarticle.recommend.server.service.recommend.score.ScoreStrategy;
import com.tzld.longarticle.recommend.server.util.DateUtils;
import com.tzld.longarticle.recommend.server.util.MapBuilder;
import com.tzld.longarticle.recommend.server.util.feishu.FeiShu;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.util.Pair;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import org.springframework.web.client.RestTemplate;

import java.lang.reflect.Field;
import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

@Service
@Slf4j
public class DataDashboardService {

    @Autowired
    private ArticleRepository articleRepository;
    @Autowired
    private ArticleDetailInfoRepository articleDetailInfoRepository;
    @Autowired
    private AccountAvgInfoRepository accountAvgInfoRepository;
    @Autowired
    private PublishSortLogRepository publishSortLogRepository;
    @Autowired
    private LongArticleBaseMapper longArticleBaseMapper;
    @Autowired
    private AigcBaseMapper aigcBaseMapper;
    @Autowired
    private PublishContentMapper publishContentMapper;
    @Autowired
    private PublishAccountRepository publishAccountRepository;
    @Autowired
    private PublishContentLayOutRepository publishContentLayOutRepository;
    @Autowired
    private PublishPlanRepository publishPlanRepository;
    @Autowired
    private ProducePlanExeRecordRepository producePlanExeRecordRepository;
    @Autowired
    private ProducePlanRepository producePlanRepository;
    @Autowired
    private ProducePlanInputSourceRepository producePlanInputSourceRepository;
    @Autowired
    private DatastatScoreRepository datastatScoreRepository;
    @Autowired
    private ArticleCategoryRepository articleCategoryRepository;
    @Autowired
    private ArticlePoolPromotionSourceRepository articlePoolPromotionSourceRepository;
    @Autowired
    private LongArticleTitleAuditRepository titleAuditRepository;
    @Autowired
    private LongArticleCrawlerVideoRepository crawlerVideoRepository;
    @Autowired
    private LongArticleTitleAuditRepository longArticleTitleAuditRepository;
    @Autowired
    private PublishSingleVideoSourceRepository videoPoolRepository;
    @Autowired
    private CrawlerBaseMapper crawlerBaseMapper;
    @Autowired
    private LongArticlesRootSourceIdRepository rootSourceIdRepository;
    @Autowired
    private DatastatSortStrategyRepository datastatSortStrategyRepository;
    @Autowired
    private LongArticlesPublishMiniprogramRepository longArticlesPublishMiniprogramRepository;
    @Autowired
    private LongArticlesNewVideoCoverRepository longArticlesNewVideoCoverRepository;

    @ApolloJsonValue("${export.account.ghId:[]}")
    private static List<String> ghIdList;
    @ApolloJsonValue("${audit.producePlan.list:[]}")
    private static List<String> auditProducePlanList;
    private static final String dailyDetailSheetToken = "M0pLs3uF6hfL0htn2dMcB9eFn8e";
    private static final String dailySafeSheetToken = "Xoass3ZGYhi9BVtZDoMclGFpnYe";

    public void export(String beginDate, String endDate) {
        List<String> dateStrList = DateUtils.getBeforeDays(beginDate, endDate, 5);
        // 滚动删除，仅保留最近14天内容
        List<String> delDateStrList = DateUtils.getBeforeDays(null, null, 14);
        exportFeishuNewSortStrategy(dateStrList, ArticleTypeEnum.QUNFA.getVal(), StatusEnum.ZERO.getCode(),
                dailyDetailSheetToken, "7d4e12", delDateStrList);
    }

    @XxlJob("scheduledExport")
    public ReturnT<String> scheduledExport(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 5);
        // 滚动删除，仅保留最近14天内容
        List<String> delDateStrList = DateUtils.getBeforeDays(null, null, 14);
        exportFeishuNewSortStrategy(dateStrList, ArticleTypeEnum.QUNFA.getVal(), StatusEnum.ZERO.getCode(),
                dailyDetailSheetToken, "7d4e12", delDateStrList);
        return ReturnT.SUCCESS;
    }

    public void exportWuXianLiu(String beginDate, String endDate) {
        List<String> dateStrList = DateUtils.getBeforeDays(beginDate, endDate, 5);
        exportFeishuNewSortStrategy(dateStrList, ArticleTypeEnum.WUXIANLIU.getVal(), StatusEnum.ONE.getCode(),
                dailyDetailSheetToken, "Ucycvw", null);
    }

    @XxlJob("scheduledExportWuXianLiu")
    public ReturnT<String> scheduledExportWuXianLiu(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 5);
        exportFeishuNewSortStrategy(dateStrList, ArticleTypeEnum.WUXIANLIU.getVal(), StatusEnum.ONE.getCode(),
                dailyDetailSheetToken, "Ucycvw", null);
        return ReturnT.SUCCESS;
    }


    private void exportFeishuNewSortStrategy(List<String> dateStrList, String articleType, Integer filter,
                                             String sheetToken, String sheetId, List<String> delDateStrList) {
        String minDate = dateStrList.stream().min(String::compareTo).orElse("");
        String maxDate = dateStrList.stream().max(String::compareTo).orElse("");
        List<NewSortStrategyExport> newContentsYesData = newSortStrategyData(minDate, maxDate, articleType, filter);
        if (CollectionUtil.isEmpty(newContentsYesData)) {
            return;
        }

        int rowNum = newContentsYesData.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = NewSortStrategyExport.class.getDeclaredFields();
        for (NewSortStrategyExport datum : newContentsYesData) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("J", "0.00%"),
                        Pair.of("K", "0.00%"),
                        Pair.of("L", "0.00%"),
                        Pair.of("M", "0.00%"),
                        Pair.of("N", "0.00%"),
                        Pair.of("O", "0.00%"),
                        Pair.of("P", "0.00%"),
                        Pair.of("Q", "0.00%"),
                        Pair.of("R", "0.00%"),
                        Pair.of("S", "0.00%"),
                        Pair.of("T", "0.00%")
                );
        doSendFeishuSheet(dateStrList, sheetToken, sheetId, rowNum, rows, 2, styles, delDateStrList, null);
    }

    public List<NewSortStrategyExport> newSortStrategyData(String beginDate, String endDate,
                                                           String articleType, Integer filter) {
        long beginTimestamp = DateUtils.dateStrToTimestamp(beginDate, "yyyyMMdd");
        long endTimestamp = DateUtils.dateStrToTimestamp(endDate, "yyyyMMdd") + 86400;
        List<AccountAvgInfo> accountAvgInfoList = accountAvgInfoRepository.findAll();
        log.info("newSortStrategyData accountAvgInfoList finish");
        List<String> ghIds = accountAvgInfoList.stream().map(AccountAvgInfo::getGhId).distinct().collect(Collectors.toList());

        List<Article> articleList = articleRepository.getByGhIdInAndPublishTimestampBetweenAndTypeEquals(ghIds,
                beginTimestamp, endTimestamp, articleType);
        Map<String, Map<String, Map<Integer, Article>>> articleMap = articleList.stream().collect(Collectors.groupingBy(Article::getGhId,
                Collectors.groupingBy(Article::getAppMsgId, Collectors.toMap(Article::getItemIndex, o -> o))));
        log.info("newSortStrategyData articleList finish");
        Set<String> snList = articleList.stream().map(Article::getWxSn).collect(Collectors.toSet());
        List<ArticleDetailInfo> articleDetailInfoList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(new ArrayList<>(snList), 1000)) {
            articleDetailInfoList.addAll(articleDetailInfoRepository.getByWxSnIn(partitions));
        }
        log.info("newSortStrategyData articleDetailInfoList finish");
        Map<String, List<ArticleDetailInfo>> articleDetailInfoMap = articleDetailInfoList.stream()
                .collect(Collectors.groupingBy(ArticleDetailInfo::getWxSn));
        List<PublishSortLog> sortLogList = publishSortLogRepository.findByGhIdInAndDateStrBetween(ghIds, beginDate, endDate);
        log.info("newSortStrategyData sortLogList finish");
        Map<String, Map<String, Map<String, PublishSortLog>>> sortStrategyMap = sortLogList.stream()
                .collect(Collectors.groupingBy(PublishSortLog::getGhId,
                        Collectors.groupingBy(PublishSortLog::getDateStr, Collectors.toMap(PublishSortLog::getTitle,
                                Function.identity(), (existing, replacement) -> existing))));
        Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap = accountAvgInfoList.stream()
                .filter(o -> Objects.nonNull(o.getReadAvg()) && o.getReadAvg() > 0 && o.getFans() > 1000)
                .collect(Collectors.groupingBy(AccountAvgInfo::getGhId, Collectors.groupingBy(AccountAvgInfo::getUpdateTime,
                        Collectors.toMap(AccountAvgInfo::getPosition, o -> o))));
        // 获取发布账号
        List<PublishAccount> publishAccountList = publishAccountRepository.getAllByGhIdIn(ghIds);
        log.info("newSortStrategyData publishAccountList finish");
        Map<String, PublishAccount> publishAccountMap = publishAccountList.stream().collect(Collectors.toMap(PublishAccount::getGhId, o -> o));
        // 获取发布内容
        List<PublishContentParam> publishContentParamList = articleList.stream().map(article -> {
            PublishContentParam item = new PublishContentParam();
            item.setTitle(article.getTitle());
            PublishAccount account = publishAccountMap.get(article.getGhId());
            if (Objects.nonNull(account)) {
                item.setPublishAccountId(account.getId());
                return item;
            }
            return null;
        }).filter(Objects::nonNull).collect(Collectors.toList());
        List<PublishContentDTO> publishContents = new ArrayList<>();
        for (List<PublishContentParam> partitions : Lists.partition(publishContentParamList, 100)) {
            publishContents.addAll(publishContentMapper.getPublishContentByTitle(partitions));
        }
        if (CollectionUtils.isEmpty(publishContents)) {
            return new ArrayList<>();
        }
        log.info("newSortStrategyData publishContents finish");
        Map<String, Map<String, Map<Long, PublishContentDTO>>> publishContentMap = publishContents.stream()
                .filter(o -> Objects.nonNull(o.getPublishTimestamp()))
                .sorted(Comparator.comparingLong(PublishContentDTO::getPublishTimestamp)).collect(
                        Collectors.groupingBy(PublishContentDTO::getPublishAccountId,
                                Collectors.groupingBy(PublishContentDTO::getTitle,
                                        Collectors.toMap(PublishContentDTO::getPublishTimestamp, o -> o,
                                                (existing, replacement) -> replacement))));
        // 获取发布内容排版
        List<String> publishContentIds = publishContents.stream().map(PublishContentDTO::getId).collect(Collectors.toList());
        List<PublishContentLayout> publishContentLayoutList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(publishContentIds, 1000)) {
            publishContentLayoutList.addAll(publishContentLayOutRepository.findByPublishContentIdIn(partitions));
        }
        log.info("newSortStrategyData publishContentLayoutList finish");
        Map<String, PublishContentLayout> publishContentLayoutMap = publishContentLayoutList.stream()
                .collect(Collectors.toMap(PublishContentLayout::getPublishContentId, o -> o,
                        (existing, replacement) -> replacement));
        //获取发布计划
        List<String> publishPlanIds = publishContents.stream().map(PublishContentDTO::getPlanId).distinct()
                .collect(Collectors.toList());
        List<PublishPlan> publishPlanList = publishPlanRepository.findByIdIn(publishPlanIds);
        log.info("newSortStrategyData publishPlanList finish");
        Map<String, PublishPlan> publishPlanMap = publishPlanList.stream()
                .collect(Collectors.toMap(PublishPlan::getId, o -> o));
        // 获取生成记录
        List<String> contentSourceIds = publishContents.stream()
                .filter(o -> Arrays.asList(1, 2).contains(o.getSourceType()))
                .map(PublishContentDTO::getSourceId).distinct().collect(Collectors.toList());
        List<ProducePlanExeRecord> planExeRecordList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(contentSourceIds, 1000)) {
            planExeRecordList.addAll(producePlanExeRecordRepository.findByPlanExeIdIn(partitions));
        }
        log.info("newSortStrategyData planExeRecordList finish");
        List<String> videoPoolSourceIds = publishContents.stream()
                .filter(o -> o.getSourceType().equals(PublishPlanInputSourceTypesEnum.longArticleVideoPoolSource.getVal()))
                .map(PublishContentDTO::getSourceId).distinct().collect(Collectors.toList());
        List<PublishSingleVideoSource> videoPoolList = videoPoolRepository.getByContentTraceIdIn(videoPoolSourceIds);
        Map<String, PublishSingleVideoSource> videoPoolSourceMap = videoPoolList.stream()
                .collect(Collectors.toMap(PublishSingleVideoSource::getContentTraceId, o -> o));
        log.info("newSortStrategyData videoPoolList finish");
        Map<String, ProducePlanExeRecord> planExeRecordMap = planExeRecordList.stream()
                .collect(Collectors.toMap(ProducePlanExeRecord::getPlanExeId, o -> o));
        // 获取生成计划
        List<String> producePlanIds = planExeRecordList.stream().map(ProducePlanExeRecord::getPlanId).distinct()
                .collect(Collectors.toList());
        List<ProducePlan> producePlanList = producePlanRepository.findByIdIn(producePlanIds);
        log.info("newSortStrategyData producePlanList finish");
        Map<String, ProducePlan> producePlanMap = producePlanList.stream()
                .collect(Collectors.toMap(ProducePlan::getId, o -> o));
        // 获取生成计划输入
        List<ProducePlanInputSource> inputSourceList = producePlanInputSourceRepository.findByPlanIdIn(producePlanIds);
        log.info("newSortStrategyData inputSourceList finish");
        Map<String, List<ProducePlanInputSource>> inputSourceMap = inputSourceList.stream()
                .collect(Collectors.groupingBy(ProducePlanInputSource::getPlanId));
        // 获取抓取内容关联
        List<String> crawlerChannelContentIds = publishContents.stream().map(PublishContentDTO::getCrawlerChannelContentId)
                .distinct().collect(Collectors.toList());
        List<CrawlerPlanResultRel> resultRelList = aigcBaseMapper.getCrawlerPlanRelByChannelContentIds(crawlerChannelContentIds);
        log.info("newSortStrategyData resultRelList finish");
        Map<String, List<CrawlerPlanResultRel>> resultRelMap = resultRelList.stream()
                .collect(Collectors.groupingBy(CrawlerPlanResultRel::getChannelSourceId));
        // 获取抓取计划
        List<String> crawlerPlanIds = resultRelList.stream().map(CrawlerPlanResultRel::getPlanId).distinct()
                .collect(Collectors.toList());
        List<CrawlerPlan> crawlerPlanList = aigcBaseMapper.getCrawlerPlanByPlanIds(crawlerPlanIds);
        log.info("newSortStrategyData crawlerPlanList finish");
        Map<String, CrawlerPlan> crawlerPlanMap = crawlerPlanList.stream()
                .collect(Collectors.toMap(CrawlerPlan::getId, o -> o));
        // 获取小程序任务
        List<MiniprogramTaskParam> miniprogramTaskParamList = new ArrayList<>();
        Set<String> distinct = new HashSet<>();
        for (PublishContentDTO publishContent : publishContents) {
            String key = publishContent.getPlanId() + publishContent.getPublishAccountId();
            if (distinct.contains(key)) {
                continue;
            } else {
                distinct.add(key);
            }
            MiniprogramTaskParam param = new MiniprogramTaskParam();
            param.setAccountId(publishContent.getPublishAccountId());
            param.setPlanId(publishContent.getPlanId());
            miniprogramTaskParamList.add(param);
        }
        List<PublishPlanMiniprogramTask> miniprogramTaskList = new ArrayList<>();
        for (List<MiniprogramTaskParam> partitions : Lists.partition(miniprogramTaskParamList, 1000)) {
            miniprogramTaskList.addAll(publishContentMapper.getMiniProgramTask(partitions));
        }
        log.info("newSortStrategyData miniprogramTaskList finish");
        Map<String, List<PublishPlanMiniprogramTask>> miniprogramTaskMap = miniprogramTaskList.stream()
                .collect(Collectors.groupingBy(PublishPlanMiniprogramTask::getPlanId));
        // 源生成计划
        List<String> titleList = articleList.stream().map(Article::getTitle).distinct().collect(Collectors.toList());
        Map<String, ProducePlan> sourceTitlePlanMap = getTitleSourceProducePlanMap(titleList);
        log.info("newSortStrategyData sourceTitlePlan finish");
        // 历史发布情况
        List<String> titleMd5List = articleList.stream().map(Article::getTitleMd5).distinct().collect(Collectors.toList());
        List<Article> hisArticleList = new ArrayList<>();
        List<List<String>> titleMd5Partition = Lists.partition(new ArrayList<>(titleMd5List), 1000);
        for (List<String> titleMd5s : titleMd5Partition) {
            hisArticleList.addAll(articleRepository.getByTitleMd5InAndTypeEqualsAndStatusEquals(titleMd5s, articleType, 1));
        }
        log.info("newSortStrategyData hisArticleList finish");
        Map<String, List<Article>> hisArticleMap = hisArticleList.stream().collect(Collectors.groupingBy(Article::getTitle));
        Set<String> hisWxSnList = hisArticleList.stream().map(Article::getWxSn).collect(Collectors.toSet());
        List<ArticleDetailInfo> hisArticleDetailInfoList = new ArrayList<>();
        List<List<String>> hisSnPartition = Lists.partition(new ArrayList<>(hisWxSnList), 1000);
        for (List<String> sns : hisSnPartition) {
            hisArticleDetailInfoList.addAll(articleDetailInfoRepository.getByWxSnIn(sns));
        }
        log.info("newSortStrategyData hisArticleDetailInfoList finish");
        Map<String, List<ArticleDetailInfo>> hisArticleDetailInfoMap = hisArticleDetailInfoList.stream()
                .collect(Collectors.groupingBy(ArticleDetailInfo::getWxSn));

        // result
        List<DatastatSortStrategy> saveList = new ArrayList<>();
        for (Article article : articleList) {
            DatastatSortStrategy obj = new DatastatSortStrategy();
            obj.setType(articleType);
            List<ArticleDetailInfo> articleDetailInfos = articleDetailInfoMap.get(article.getWxSn());
            setObjArticleDetailInfo(article, obj, articleDetailInfos);
            Article firstArticle = articleMap.get(article.getGhId()).get(article.getAppMsgId()).get(1);
            Map<String, Map<String, PublishSortLog>> dateStrategy = sortStrategyMap.get(article.getGhId());
            Map<String, AccountAvgInfo> indexAvgInfoMap = getDateAccountAvgInfo(accountAvgInfoIndexMap, article.getGhId(),
                    article.getPublishTimestamp(), article.getItemIndex());
            AccountAvgInfo firstAvgInfo = getAccountAvgInfo(accountAvgInfoIndexMap, article.getGhId(),
                    article.getPublishTimestamp(), 1);
            String date = DateUtils.timestampToYMDStr(article.getPublishTimestamp(), "yyyyMMdd");
            setObjBaseInfo(article, obj, date);
            if (Objects.nonNull(firstArticle)) {
                obj.setFirstViewCount(firstArticle.getShowViewCount());
            }
            if (Objects.nonNull(firstAvgInfo)) {
                obj.setFirstAvgViewCount(firstAvgInfo.getReadAvg());
            }
            if (Objects.nonNull(dateStrategy)) {
                Map<String, PublishSortLog> titleStrategyMap = dateStrategy.get(date);
                if (Objects.nonNull(titleStrategyMap)) {
                    PublishSortLog sortLog = titleStrategyMap.get(article.getTitle());
                    if (Objects.nonNull(sortLog)) {
                        String strategy = sortLog.getStrategy();
                        if (!StringUtils.hasText(sortLog.getStrategy())) {
                            if (Objects.equals(articleType, ArticleTypeEnum.WUXIANLIU.getVal())) {
                                strategy = RankStrategyEnum.INFINITE_STRATEGY.getStrategy();
                            } else {
                                for (Map.Entry<String, PublishSortLog> entry : titleStrategyMap.entrySet()) {
                                    strategy = entry.getValue().getStrategy();
                                    break;
                                }
                            }
                        }
                        obj.setSourceType(sortLog.getSourceType());
                        obj.setSourceId(sortLog.getSourceId());
                        obj.setStrategy(strategy);
                    }
                }
            }
            if (!StringUtils.hasText(obj.getStrategy()) &&
                    Objects.equals(articleType, ArticleTypeEnum.WUXIANLIU.getVal())) {
                obj.setStrategy(RankStrategyEnum.INFINITE_STRATEGY.getStrategy());
            }
            setObjSortInfo(article, obj, date);
            setObjAvgInfo(article, obj, indexAvgInfoMap);
            setObjHisRateInfo(article, obj, hisArticleMap, accountAvgInfoIndexMap, hisArticleDetailInfoMap);
            // aigc 数据
            setObjAigcInfo(article, obj, date, publishAccountMap, publishContentMap, publishContentLayoutMap,
                    publishPlanMap, miniprogramTaskMap, planExeRecordMap, producePlanMap, inputSourceMap,
                    resultRelMap, crawlerPlanMap, sourceTitlePlanMap, videoPoolSourceMap);
            saveList.add(obj);
        }
        log.info("newSortStrategyData buildData finish");
        if (CollectionUtil.isNotEmpty(saveList) && filter == StatusEnum.ONE.getCode()) {
            saveList = saveList.stream()
                    .filter(o -> Objects.nonNull(o.getPublishMiniProgramNum()) && o.getPublishMiniProgramNum() > 0)
                    .collect(Collectors.toList());
        }
        saveList.sort(Comparator.comparing(DatastatSortStrategy::getDateStr).reversed()
                .thenComparing(DatastatSortStrategy::getGhId).thenComparing(DatastatSortStrategy::getPosition));
        try {
            if (CollectionUtils.isNotEmpty(saveList)) {
                longArticleBaseMapper.deleteByDateStrBetween(beginDate, endDate, articleType);
                for (List<DatastatSortStrategy> saveListPartition : Lists.partition(saveList, 1000)) {
                    longArticleBaseMapper.batchInsertDatastatSortStrategy(saveListPartition);
                }
            }
        } catch (Exception e) {
            log.error("DatastatSortStrategy save error:{}", e.getMessage());
        }
        log.info("newSortStrategyData finish");
        return NewSortStrategyExport.dbObjToExportObj(saveList);
    }

    private void setObjSortInfo(Article article, DatastatSortStrategy obj, String date) {
        if (StringUtils.hasText(obj.getStrategy())) {
            return;
        }
        List<String> dateStrList = DateUtils.getBeforeDays(date, date, 7);
        List<PublishSortLog> sortLogList = publishSortLogRepository.getByGhIdInAndDateStrIn(
                Collections.singletonList(article.getGhId()), dateStrList);
        if (CollectionUtils.isEmpty(sortLogList)) {
            return;
        }
        for (PublishSortLog sortLog : sortLogList) {
            if (sortLog.getTitle().equals(article.getTitle())
                    && Objects.equals(sortLog.getIndex(), article.getItemIndex())) {
                obj.setSourceType(sortLog.getSourceType());
                obj.setSourceId(sortLog.getSourceId());
                obj.setStrategy(sortLog.getStrategy());
                break;
            }
        }
    }

    private void setObjAigcInfo(Article article, DatastatSortStrategy obj, String date,
                                Map<String, PublishAccount> publishAccountMap,
                                Map<String, Map<String, Map<Long, PublishContentDTO>>> publishContentMap,
                                Map<String, PublishContentLayout> publishContentLayoutMap,
                                Map<String, PublishPlan> publishPlanMap,
                                Map<String, List<PublishPlanMiniprogramTask>> miniprogramTaskMap,
                                Map<String, ProducePlanExeRecord> planExeRecordMap,
                                Map<String, ProducePlan> producePlanMap,
                                Map<String, List<ProducePlanInputSource>> inputSourceMap,
                                Map<String, List<CrawlerPlanResultRel>> resultRelMap,
                                Map<String, CrawlerPlan> crawlerPlanMap,
                                Map<String, ProducePlan> sourceTitlePlanMap,
                                Map<String, PublishSingleVideoSource> videoPoolSourceMap) {
        PublishAccount publishAccount = publishAccountMap.get(article.getGhId());
        obj.setAccountCreateTimestamp(publishAccount.getCreateTimestamp() / 1000);
        Map<String, Map<Long, PublishContentDTO>> titleContentMap = publishContentMap.get(publishAccount.getId());
        if (Objects.isNull(titleContentMap)) {
            return;
        }
        Map<Long, PublishContentDTO> publishTimeContentMap = titleContentMap.get(article.getTitle());
        if (Objects.isNull(publishTimeContentMap) || publishTimeContentMap.isEmpty()) {
            return;
        }
        PublishContentDTO publishContent = null;
        List<String> hisPublishTimeStrList = publishTimeContentMap.keySet().stream()
                .map(o -> DateUtils.timestampToYMDStr(o / 1000, "yyyyMMdd")).collect(Collectors.toList());
        String publishTime = DateUtils.findNearestDate(hisPublishTimeStrList, date, "yyyyMMdd");
        for (Map.Entry<Long, PublishContentDTO> entry : publishTimeContentMap.entrySet()) {
            String str = DateUtils.timestampToYMDStr(entry.getKey() / 1000, "yyyyMMdd");
            if (publishTime.equals(str)) {
                publishContent = entry.getValue();
            }
        }
        if (Objects.isNull(publishContent)) {
            return;
        }
        PublishContentLayout layout = publishContentLayoutMap.get(publishContent.getId());
        List<ProduceAuditLayoutContentObjVO> layoutList = JSON.parseArray(layout.getContent(), ProduceAuditLayoutContentObjVO.class);
        if (CollectionUtil.isNotEmpty(layoutList)) {
            long miniProgramNum = layoutList.stream().filter(o -> o.getType() == 4).count();
            obj.setPublishMiniProgramNum((int) miniProgramNum);
        }
        PublishPlan publishPlan = publishPlanMap.get(publishContent.getPlanId());
        obj.setPublishPlanName(publishPlan.getName());
        // 插入小程序任务
        List<PublishPlanMiniprogramTask> miniprogramTasks = miniprogramTaskMap.get(publishPlan.getId());
        if (CollectionUtil.isNotEmpty(miniprogramTasks)) {
            miniprogramTasks = miniprogramTasks.stream()
                    .filter(o -> o.getAccountIds().contains(publishAccount.getId()))
                    .collect(Collectors.toList());
            if (CollectionUtil.isNotEmpty(miniprogramTasks)) {
                obj.setPublishMiniProgramInsertStrategy(miniprogramTasks.get(0).getStrategy());
                obj.setPublishMiniProgramInsertUseType(miniprogramTasks.get(0).getMiniprogramUseType() == 1 ? "自然流" : "投流");
            }
        }
        List<ProducePlanInputSource> producePlanInputSourceList = new ArrayList<>();
        if (Arrays.asList(1, 2).contains(publishContent.getSourceType())) {
            ProducePlanExeRecord record = planExeRecordMap.get(publishContent.getSourceId());
            if (Objects.nonNull(record)) {
                ProducePlan producePlan = producePlanMap.get(record.getPlanId());
                obj.setProducePlanName(producePlan.getName());
                obj.setProducePlanTag(producePlan.getPlanTag());
            }
            producePlanInputSourceList = inputSourceMap.get(record.getPlanId());
        }
        if (publishContent.getSourceType().equals(PublishPlanInputSourceTypesEnum.longArticleVideoPoolSource.getVal())) {
            PublishSingleVideoSource videoPoolSource = videoPoolSourceMap.get(publishContent.getSourceId());
            if (Objects.nonNull(videoPoolSource)) {
                ContentPoolEnum poolEnum = ContentPoolEnum.from(videoPoolSource.getFlowPoolLevel());
                obj.setProducePlanName("视频内容池-" + poolEnum.getDescription());
                VideoPoolPlatformEnum platformEnum = VideoPoolPlatformEnum.from(videoPoolSource.getPlatform());
                if (Objects.nonNull(platformEnum)) {
                    obj.setCrawlerPlanName(platformEnum.getDescription());
                } else {
                    obj.setCrawlerPlanName(videoPoolSource.getPlatform());
                }
            }
        }
        List<CrawlerPlanResultRel> crawlerPlanRelList = resultRelMap.get(publishContent.getCrawlerChannelContentId());
        if (CollectionUtil.isNotEmpty(crawlerPlanRelList) && CollectionUtil.isNotEmpty(producePlanInputSourceList)) {
            List<String> inputSourceValues = producePlanInputSourceList.stream()
                    .map(ProducePlanInputSource::getInputSourceValue).collect(Collectors.toList());
            List<CrawlerPlan> crawlerPlanItemList = new ArrayList<>();
            for (CrawlerPlanResultRel crawlerPlanResultRel : crawlerPlanRelList) {
                crawlerPlanItemList.add(crawlerPlanMap.get(crawlerPlanResultRel.getPlanId()));
            }
            for (CrawlerPlan crawlerPlan : crawlerPlanItemList) {
                if (inputSourceValues.contains(crawlerPlan.getId())) {
                    obj.setCrawlerPlanName(crawlerPlan.getName());
                    obj.setCrawlerPlanTag(crawlerPlan.getPlanTag());
                    break;
                }
            }
        }
        ProducePlan sourceProducePlan = sourceTitlePlanMap.get(article.getTitle());
        if (Objects.nonNull(sourceProducePlan)) {
            obj.setSourceProducePlanName(sourceProducePlan.getName());
        }
    }

    private void setObjHisRateInfo(Article article, DatastatSortStrategy obj,
                                   Map<String, List<Article>> hisArticleMap,
                                   Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap,
                                   Map<String, List<ArticleDetailInfo>> hisArticleDetailInfoMap) {
        List<Article> hisArticles = hisArticleMap.getOrDefault(article.getTitle(), new ArrayList<>());
        hisArticles = hisArticles.stream().filter(o -> o.getPublishTimestamp() < (article.getPublishTimestamp() - 3600 * 8)
                && (1 == o.getItemIndex() || 2 == o.getItemIndex())
                && !ScoreStrategy.hisContentLateFilter(o.getPublishTimestamp())).collect(Collectors.toList());
        Integer readCount = 0;
        Double readAvgCount = 0.0;
        int firstCount = 0;
        int fission0Count = 0;
        for (Article hisArticle : hisArticles) {
            readCount += hisArticle.getShowViewCount();
            AccountAvgInfo accountAvgInfo = getAccountAvgInfo(accountAvgInfoIndexMap, hisArticle.getGhId(),
                    hisArticle.getPublishTimestamp(), hisArticle.getItemIndex());
            if (Objects.nonNull(accountAvgInfo)) {
                readAvgCount += accountAvgInfo.getReadAvg();
            }
            List<ArticleDetailInfo> hisADIList = hisArticleDetailInfoMap.get(hisArticle.getWxSn());
            if (CollectionUtil.isNotEmpty(hisADIList)) {
                Date hisMinDate = hisADIList.stream().map(ArticleDetailInfo::getRecallDt).min(Date::compareTo).orElse(new Date());
                for (ArticleDetailInfo articleDetailInfo : hisADIList) {
                    if (articleDetailInfo.getRecallDt().equals(hisMinDate)) {
                        if (Objects.nonNull(articleDetailInfo.getFirstLevel())) {
                            firstCount += articleDetailInfo.getFirstLevel();
                        }
                        if (Objects.nonNull(articleDetailInfo.getFission0())) {
                            fission0Count += articleDetailInfo.getFission0();
                        }
                    }
                }
            }
        }
        if (readAvgCount > 0) {
            obj.setHisReadRate(readCount / readAvgCount);
        }
        if (readCount > 0) {
            obj.setHisFirstReadRate(firstCount / (double) readCount);
        }
        if (firstCount > 0) {
            obj.setHisFission0FirstRate(fission0Count / (double) firstCount);
        }
    }

    private void setObjBaseInfo(Article article, DatastatSortStrategy obj, String date) {
        obj.setGhId(article.getGhId());
        obj.setAccountName(article.getAccountName());
        obj.setTitle(article.getTitle());
        obj.setLink(article.getContentUrl());
        obj.setPosition(article.getItemIndex());
        obj.setViewCount(article.getShowViewCount());
        obj.setDateStr(date);
        obj.setPublishTime(DateUtils.timestampToYMDStr(article.getPublishTimestamp(), "HH:mm:ss"));
        obj.setWxSn(article.getWxSn());
        obj.setPublishTimestamp(article.getPublishTimestamp());
    }

    private void setObjArticleDetailInfo(Article article, DatastatSortStrategy obj, List<ArticleDetailInfo> articleDetailInfos) {
        if (CollectionUtils.isNotEmpty(articleDetailInfos)) {
            Date publishDate = DateUtils.getStartDateOfDay(article.getPublishTimestamp());
            articleDetailInfos = articleDetailInfos.stream().filter(o -> !o.getRecallDt().before(publishDate))
                    .collect(Collectors.toList());
            Date minDate = articleDetailInfos.stream().map(ArticleDetailInfo::getRecallDt).min(Date::compareTo).orElse(new Date());
            Date secondDate = articleDetailInfos.stream().map(ArticleDetailInfo::getRecallDt).filter(o -> o.after(minDate)).min(Date::compareTo).orElse(new Date());
            Date thirdDate = articleDetailInfos.stream().map(ArticleDetailInfo::getRecallDt).filter(o -> o.after(secondDate)).min(Date::compareTo).orElse(new Date());
            int sumFirstLevel = 0;
            int sumFission0 = 0, sumFission0Head = 0, sumFission0Recommend = 0;
            int sumFission1 = 0, sumFission1Head = 0, sumFission1Recommend = 0;
            int sumFission2 = 0, sumFission2Head = 0, sumFission2Recommend = 0;
            int sumSecondFirstLevel = 0;
            int sumSecondFission0 = 0, sumSecondFission0Head = 0, sumSecondFission0Recommend = 0;
            int sumSecondFission1 = 0, sumSecondFission1Head = 0, sumSecondFission1Recommend = 0;
            int sumSecondFission2 = 0, sumSecondFission2Head = 0, sumSecondFission2Recommend = 0;
            int sumThirdFirstLevel = 0;
            int sumThirdFission0 = 0, sumThirdFission0Head = 0, sumThirdFission0Recommend = 0;
            int sumThirdFission1 = 0, sumThirdFission1Head = 0, sumThirdFission1Recommend = 0;
            int sumThirdFission2 = 0, sumThirdFission2Head = 0, sumThirdFission2Recommend = 0;
            for (ArticleDetailInfo articleDetailInfo : articleDetailInfos) {
                if (articleDetailInfo.getRecallDt().equals(minDate)) {
                    sumFirstLevel += Optional.ofNullable(articleDetailInfo.getFirstLevel()).orElse(0);
                    sumFission0 += Optional.ofNullable(articleDetailInfo.getFission0()).orElse(0);
                    sumFission0Head += Optional.ofNullable(articleDetailInfo.getFission0Head()).orElse(0);
                    sumFission0Recommend += Optional.ofNullable(articleDetailInfo.getFission0Recommend()).orElse(0);
                    sumFission1 += Optional.ofNullable(articleDetailInfo.getFission1()).orElse(0);
                    sumFission1Head += Optional.ofNullable(articleDetailInfo.getFission1Head()).orElse(0);
                    sumFission1Recommend += Optional.ofNullable(articleDetailInfo.getFission1Recommend()).orElse(0);
                    sumFission2 += Optional.ofNullable(articleDetailInfo.getFission2()).orElse(0);
                    sumFission2Head += Optional.ofNullable(articleDetailInfo.getFission2Head()).orElse(0);
                    sumFission2Recommend += Optional.ofNullable(articleDetailInfo.getFission2Recommend()).orElse(0);
                }
                if (articleDetailInfo.getRecallDt().equals(secondDate)) {
                    sumSecondFirstLevel += Optional.ofNullable(articleDetailInfo.getFirstLevel()).orElse(0);
                    sumSecondFission0 += Optional.ofNullable(articleDetailInfo.getFission0()).orElse(0);
                    sumSecondFission0Head += Optional.ofNullable(articleDetailInfo.getFission0Head()).orElse(0);
                    sumSecondFission0Recommend += Optional.ofNullable(articleDetailInfo.getFission0Recommend()).orElse(0);
                    sumSecondFission1 += Optional.ofNullable(articleDetailInfo.getFission1()).orElse(0);
                    sumSecondFission1Head += Optional.ofNullable(articleDetailInfo.getFission1Head()).orElse(0);
                    sumSecondFission1Recommend += Optional.ofNullable(articleDetailInfo.getFission1Recommend()).orElse(0);
                    sumSecondFission2 += Optional.ofNullable(articleDetailInfo.getFission2()).orElse(0);
                    sumSecondFission2Head += Optional.ofNullable(articleDetailInfo.getFission2Head()).orElse(0);
                    sumSecondFission2Recommend += Optional.ofNullable(articleDetailInfo.getFission2Recommend()).orElse(0);
                }
                if (articleDetailInfo.getRecallDt().equals(thirdDate)) {
                    sumThirdFirstLevel += Optional.ofNullable(articleDetailInfo.getFirstLevel()).orElse(0);
                    sumThirdFission0 += Optional.ofNullable(articleDetailInfo.getFission0()).orElse(0);
                    sumThirdFission0Head += Optional.ofNullable(articleDetailInfo.getFission0Head()).orElse(0);
                    sumThirdFission0Recommend += Optional.ofNullable(articleDetailInfo.getFission0Recommend()).orElse(0);
                    sumThirdFission1 += Optional.ofNullable(articleDetailInfo.getFission1()).orElse(0);
                    sumThirdFission1Head += Optional.ofNullable(articleDetailInfo.getFission1Head()).orElse(0);
                    sumThirdFission1Recommend += Optional.ofNullable(articleDetailInfo.getFission1Recommend()).orElse(0);
                    sumThirdFission2 += Optional.ofNullable(articleDetailInfo.getFission2()).orElse(0);
                    sumThirdFission2Head += Optional.ofNullable(articleDetailInfo.getFission2Head()).orElse(0);
                    sumThirdFission2Recommend += Optional.ofNullable(articleDetailInfo.getFission2Recommend()).orElse(0);
                }
            }
            obj.setFirstLevel(sumFirstLevel);
            obj.setFission0(sumFission0);
            obj.setFission0Head(sumFission0Head);
            obj.setFission0Recommend(sumFission0Recommend);
            obj.setFission1(sumFission1);
            obj.setFission1Head(sumFission1Head);
            obj.setFission1Recommend(sumFission1Recommend);
            obj.setFission2(sumFission2);
            obj.setFission2Head(sumFission2Head);
            obj.setFission2Recommend(sumFission2Recommend);
            obj.setSecondFirstLevel(sumSecondFirstLevel);
            obj.setSecondFission0(sumSecondFission0);
            obj.setSecondFission0Head(sumSecondFission0Head);
            obj.setSecondFission0Recommend(sumSecondFission0Recommend);
            obj.setSecondFission1(sumSecondFission1);
            obj.setSecondFission1Head(sumSecondFission1Head);
            obj.setSecondFission1Recommend(sumSecondFission1Recommend);
            obj.setSecondFission2(sumSecondFission2);
            obj.setSecondFission2Head(sumSecondFission2Head);
            obj.setSecondFission2Recommend(sumSecondFission2Recommend);
            obj.setThirdFirstLevel(sumThirdFirstLevel);
            obj.setThirdFission0(sumThirdFission0);
            obj.setThirdFission0Head(sumThirdFission0Head);
            obj.setThirdFission0Recommend(sumThirdFission0Recommend);
            obj.setThirdFission1(sumThirdFission1);
            obj.setThirdFission1Head(sumThirdFission1Head);
            obj.setThirdFission1Recommend(sumThirdFission1Recommend);
            obj.setThirdFission2(sumThirdFission2);
            obj.setThirdFission2Head(sumThirdFission2Head);
            obj.setThirdFission2Recommend(sumThirdFission2Recommend);
        }
    }

    private void setObjAvgInfo(Article article, DatastatSortStrategy obj, Map<String, AccountAvgInfo> indexAvgInfoMap) {
        if (MapUtils.isNotEmpty(indexAvgInfoMap)) {
            AccountAvgInfo info = null;
            for (String index : indexAvgInfoMap.keySet()) {
                info = indexAvgInfoMap.get(index);
                break;
            }
            if (Objects.nonNull(info)) {
                obj.setAccountMode(info.getAccountMode());
                obj.setAccountSource(info.getAccountSource());
                obj.setAccountType(info.getAccountType());
                obj.setAccountStatus(info.getAccountStatus());
                obj.setBusinessType(AccountBusinessTypeEnum.from(info.getBusinessType()).getDescription());
                obj.setFans(info.getFans());
            }
        }
        AccountAvgInfo avgInfo = indexAvgInfoMap.get(article.getItemIndex().toString());
        if (Objects.nonNull(avgInfo)) {
            obj.setAvgViewCount(avgInfo.getReadAvg());
            if (avgInfo.getReadAvg() > 0) {
                obj.setReadRate((article.getShowViewCount() * 1.0) / avgInfo.getReadAvg());
                if (Objects.nonNull(obj.getFission0())) {
                    obj.setFission0ReadAvgRate((obj.getFission0() * 1.0) / avgInfo.getReadAvg());
                    obj.setFission0ReadAvg100Rate((obj.getFission0() * 1.0) / (avgInfo.getReadAvg() + 100));
                    obj.setFission0ReadAvg500Rate((obj.getFission0() * 1.0) / (avgInfo.getReadAvg() + 500));
                    obj.setFission0ReadAvg1000Rate((obj.getFission0() * 1.0) / (avgInfo.getReadAvg() + 1000));
                }
            }
            if (avgInfo.getFans() > 0) {
                obj.setReadFansRate((article.getShowViewCount() * 1.0) / avgInfo.getFans());
            }
        }
        if (Objects.nonNull(obj.getFirstLevel()) && obj.getFirstLevel() > 0) {
            if (Objects.nonNull(obj.getFission0())) {
                obj.setFission0FirstRate((obj.getFission0() * 1.0) / obj.getFirstLevel());
            }
            if (Objects.nonNull(obj.getFission0Head())) {
                obj.setFission0HeadFirstRate((obj.getFission0Head() * 1.0) / obj.getFirstLevel());
            }
            if (Objects.nonNull(obj.getFission0Recommend())) {
                obj.setFission0RecommendFirstRate((obj.getFission0Recommend() * 1.0) / obj.getFirstLevel());
            }
        }
        if (article.getShowViewCount() > 0 && Objects.nonNull(obj.getFirstLevel())) {
            obj.setFirstReadRate((obj.getFirstLevel() * 1.0) / article.getShowViewCount());
        }
        if (Objects.nonNull(obj.getFission0()) && obj.getFission0() > 0 && Objects.nonNull(obj.getFission1())) {
            obj.setFission1Fission0Rate((obj.getFission1() * 1.0) / obj.getFission0());
        }
    }

    private Map<String, ProducePlan> getTitleSourceProducePlanMap(List<String> titleList) {
        List<ProduceContentDTO> sourceProduceContentList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(titleList, 1000)) {
            sourceProduceContentList.addAll(publishContentMapper.getSourceProduceContentByTitles(partitions));
        }
        Map<String, List<ProduceContentDTO>> sourceProduceContentMap = sourceProduceContentList.stream()
                .collect(Collectors.groupingBy(ProduceContentDTO::getTitle));
        Map<String, String> sourceTitlePlanIdMap = new HashMap<>();
        List<String> sourceProducePlanIds = new ArrayList<>();
        for (Map.Entry<String, List<ProduceContentDTO>> entry : sourceProduceContentMap.entrySet()) {
            String title = entry.getKey();
            List<ProduceContentDTO> contentList = entry.getValue();
            contentList.sort(Comparator.comparing(ProduceContentDTO::getProduceTimestamp));
            sourceTitlePlanIdMap.put(title, contentList.get(0).getProducePlanId());
            sourceProducePlanIds.add(contentList.get(0).getProducePlanId());
        }
        List<ProducePlan> sourceProducePlanList = producePlanRepository.findByIdIn(sourceProducePlanIds);
        Map<String, ProducePlan> sourceProducePlanMap = sourceProducePlanList.stream()
                .collect(Collectors.toMap(ProducePlan::getId, o -> o));
        Map<String, ProducePlan> sourceTitlePlanMap = new HashMap<>();
        for (Map.Entry<String, String> entry : sourceTitlePlanIdMap.entrySet()) {
            String title = entry.getKey();
            String planId = entry.getValue();
            ProducePlan plan = sourceProducePlanMap.get(planId);
            sourceTitlePlanMap.put(title, plan);
        }
        return sourceTitlePlanMap;
    }


    private static void doSendFeishuSheet(List<String> dateStrList, String sheetToken, String sheetId,
                                          int rowNum, List<List<Object>> rows, Integer startRowIndex,
                                          List<Pair<String, String>> styles,
                                          List<String> delDateStrList,
                                          List<Pair<String, List<Pair<String, String>>>> thanks) {
        Pair<String, Integer> token = FeiShu.requestAccessToken();
        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.add("Authorization", "Bearer " + token.getFirst());

        delFeishuSheet(httpHeaders, sheetId, startRowIndex, delDateStrList);
        // 先删除掉已存在的dateStr数据
        HttpEntity<Object> queryEntity = new HttpEntity<>(httpHeaders);
        int deleteRowNum = rowNum < 20 ? startRowIndex + dateStrList.size() * rowNum : startRowIndex + (rowNum * 2);
        ResponseEntity<String> queryResponseEntity = restTemplate.exchange(
                String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/values/%s!A"
                        + startRowIndex + ":A" + deleteRowNum, sheetToken, sheetId),
                HttpMethod.GET, queryEntity, String.class);
        JSONArray values = JSON.parseObject(queryResponseEntity.getBody())
                .getJSONObject("data")
                .getJSONObject("valueRange")
                .getJSONArray("values");
        int count = 0;
        if (!values.isEmpty() && Objects.nonNull(values.get(0)) && !((JSONArray) values.get(0)).isEmpty()
                && Objects.nonNull(((JSONArray) values.get(0)).get(0))
                && dateStrList.contains(((JSONArray) values.get(0)).get(0).toString())) {
            for (Object value : values) {
                if (((JSONArray) value).get(0) != null) {
                    List<String> dates = ((JSONArray) value).stream().map(Object::toString).collect(Collectors.toList());
                    if (dateStrList.contains(dates.get(0))) {
                        count++;
                        continue;
                    }
                }
                break;
            }
        }
        if (count > 0) {
            int delNum = 0;
            do {
                // 删除当前日期已存在的旧数据
                httpHeaders.setContentType(MediaType.APPLICATION_JSON);
                HttpEntity<Object> deleteEntity = new HttpEntity<>(
                        String.format("{\n" +
                                "    \"dimension\": {\n" +
                                "        \"sheetId\": \"%s\",\n" +
                                "        \"majorDimension\": \"ROWS\",\n" +
                                "        \"startIndex\": %s,\n" +
                                "        \"endIndex\": %s\n" +
                                "    }\n" +
                                "}", sheetId, startRowIndex, Math.min(startRowIndex + 4000, count - delNum + startRowIndex) - 1),
                        httpHeaders);
                restTemplate.exchange(String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/dimension_range", sheetToken),
                        HttpMethod.DELETE, deleteEntity, String.class);
                delNum = Math.min(delNum + 4000, count);
            } while (delNum < count);
        }
        List<List<List<Object>>> partitions = Lists.partition(rows, 1000);
        int startRow = startRowIndex;
        for (List<List<Object>> partition : partitions) {
            // 插入数据
            HttpEntity<Object> postEntity = new HttpEntity<>(MapBuilder
                    .builder()
                    .put("valueRange", MapBuilder
                            .builder()
                            .put("range", String.format("%s!A" + startRow + ":CI", sheetId) + (partition.size() + startRow - 1))
                            .put("values", partition)
                            .build())
                    .build(), httpHeaders);
            ResponseEntity<String> response = restTemplate.exchange(String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/values_prepend",
                            sheetToken),
                    HttpMethod.POST, postEntity, String.class);
            JSONObject responseJSON = JSONObject.parseObject(response.getBody());
            if (0 != responseJSON.getInteger("code")) {
                log.error("doSendFeishuSheet write error :{}", responseJSON.getString("msg"));
            }
            startRow += partition.size();
        }
//        // 合并单元格
//        if (isMerge) {
//            HttpEntity<Object> mergeEntity = new HttpEntity<>(MapBuilder
//                    .builder()
//                    .put("range", String.format("%s!A" + startRowIndex + ":A", sheetId) + (rowNum + startRowIndex - 1))
//                    .put("mergeType", "MERGE_ALL")
//                    .build(), httpHeaders);
//            restTemplate.exchange(String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/merge_cells",
//                            sheetToken),
//                    HttpMethod.POST, mergeEntity, String.class);
//        }
        // 此处先简单处理，调整单元格为”百分比小数点“
        try {
            Thread.sleep(1000);
        } catch (Exception e) {
            log.error("export sleep error");
        }
        if (CollectionUtil.isNotEmpty(styles)) {
            startRow = startRowIndex;
            do {
                for (Pair<String, String> style : styles) {
                    HttpEntity<Map<Object, Object>> styleEntity = new HttpEntity<>(MapBuilder
                            .builder()
                            .put("appendStyle",
                                    MapBuilder
                                            .builder()
                                            .put("range", String.format("%s!%s" + startRow + ":%s", sheetId,
                                                    style.getFirst(), style.getFirst())
                                                    + (Math.min(startRow + 4000, rowNum + startRowIndex) - 1))
                                            .put("style",
                                                    MapBuilder
                                                            .builder()
                                                            .put("formatter", style.getSecond())
                                                            .build()
                                            )
                                            .build()
                            )
                            .build(), httpHeaders);
                    restTemplate.exchange(
                            String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/style",
                                    sheetToken),
                            HttpMethod.PUT,
                            styleEntity,
                            String.class
                    );
                }
                startRow += 4000;
            } while (startRow < rowNum);
        }
        if (CollectionUtil.isNotEmpty(thanks)) {
            startRow = startRowIndex;
            do {
                for (Pair<String, List<Pair<String, String>>> thank : thanks) {
                    List<String> keyList = thank.getSecond().stream().map(Pair::getFirst).collect(Collectors.toList());
                    List<String> colorList = thank.getSecond().stream().map(Pair::getSecond).collect(Collectors.toList());
                    HttpEntity<Map<Object, Object>> styleEntity = new HttpEntity<>(MapBuilder
                            .builder()
                            .put("range", String.format("%s!%s" + startRow + ":%s", sheetId,
                                    thank.getFirst(), thank.getFirst())
                                    + (Math.min(startRow + 4000, rowNum + startRowIndex) - 1))
                            .put("dataValidationType", "list")
                            .put("dataValidation", MapBuilder.builder()
                                    .put("conditionValues", keyList)
                                    .put("options", MapBuilder.builder()
                                            .put("highlightValidData", true)
                                            .put("colors", colorList)
                                            .build()
                                    ).build())
                            .build(), httpHeaders);
                    restTemplate.exchange(
                            String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/dataValidation",
                                    sheetToken),
                            HttpMethod.POST,
                            styleEntity,
                            String.class
                    );
                }
                startRow += 4000;
            } while (startRow < rowNum);
        }
    }

    public static void delFeishuSheet(HttpHeaders httpHeaders, String sheetId, Integer startRowIndex,
                                      List<String> delDateStrList) {
        if (CollectionUtil.isEmpty(delDateStrList)) {
            return;
        }
        RestTemplate restTemplate = new RestTemplate();
        HttpEntity<Object> queryEntity = new HttpEntity<>(httpHeaders);
        ResponseEntity<String> queryResponseEntity = restTemplate.exchange(
                String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/values/%s!A"
                        + startRowIndex + ":A", dailyDetailSheetToken, sheetId),
                HttpMethod.GET, queryEntity, String.class);
        JSONArray values = JSON.parseObject(queryResponseEntity.getBody())
                .getJSONObject("data")
                .getJSONObject("valueRange")
                .getJSONArray("values");
        int deleteStartRow = values.size();
        if (!values.isEmpty() && Objects.nonNull(values.get(0)) && !((JSONArray) values.get(0)).isEmpty()
                && Objects.nonNull(((JSONArray) values.get(0)).get(0))) {
            for (int i = 0; i < values.size(); i++) {
                JSONArray value = values.getJSONArray(i);
                if (value.get(0) != null) {
                    List<String> dates = value.stream().map(Object::toString).collect(Collectors.toList());
                    if (!delDateStrList.contains(dates.get(0))) {
                        deleteStartRow = i + startRowIndex;
                        break;
                    }
                }
            }
        }
        int count = values.size();
        int delCount = values.size() - deleteStartRow;
        if (delCount > 0) {
            int delNum = 0;
            do {
                // 删除当前日期已存在的旧数据
                httpHeaders.setContentType(MediaType.APPLICATION_JSON);
                HttpEntity<Object> deleteEntity = new HttpEntity<>(
                        String.format("{\n" +
                                "    \"dimension\": {\n" +
                                "        \"sheetId\": \"%s\",\n" +
                                "        \"majorDimension\": \"ROWS\",\n" +
                                "        \"startIndex\": %s,\n" +
                                "        \"endIndex\": %s\n" +
                                "    }\n" +
                                "}", sheetId, deleteStartRow, deleteStartRow + Math.min(4000, delCount - delNum + startRowIndex) - 1),
                        httpHeaders);
                ResponseEntity<String> response = restTemplate.exchange(String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/dimension_range", dailyDetailSheetToken),
                        HttpMethod.DELETE, deleteEntity, String.class);
                JSONObject responseJSON = JSONObject.parseObject(response.getBody());
                if (0 != responseJSON.getInteger("code")) {
                    log.error("doSendFeishuSheet write error :{}", responseJSON.getString("msg"));
                }
                delNum = Math.min(delNum + 4000, delCount);
            } while (delNum < delCount);
        }
    }

    @XxlJob("scheduleExportIntermediateIndicators")
    public ReturnT<String> scheduleIntermediateIndicatorsExport(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 3);
        exportFeishuIntermediateIndicators(dateStrList, dailyDetailSheetToken, "OuaLWV");
        return ReturnT.SUCCESS;
    }

    public void intermediateIndicatorsExport(String beginDate, String endDate) {
        List<String> dateStrList = DateUtils.getBeforeDays(beginDate, endDate, 3);
        exportFeishuIntermediateIndicators(dateStrList, dailyDetailSheetToken, "OuaLWV");
    }

    private void exportFeishuIntermediateIndicators(List<String> dateStrList, String sheetToken, String sheetId) {
        List<IntermediateIndicatorsExport> newContentsYesData = new ArrayList<>();
        for (String dateStr : dateStrList) {
            newContentsYesData.addAll(intermediateIndicatorsData(dateStr));
        }
        newContentsYesData.sort(Comparator.comparing(IntermediateIndicatorsExport::getDateStr).reversed()
                .thenComparing((o1, o2) -> -o1.getType().compareTo(o2.getType())));
        int rowNum = newContentsYesData.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = IntermediateIndicatorsExport.class.getDeclaredFields();
        for (IntermediateIndicatorsExport datum : newContentsYesData) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("W", "#,##0.00"),
                        Pair.of("AI", "#,##0.00"),
                        Pair.of("AN", "#,##0.00"),
                        Pair.of("BC", "#,##0.00"),
                        Pair.of("BL", "#,##0.00"),
                        Pair.of("G", "0.00%"),
                        Pair.of("P", "0.00%"),
                        Pair.of("Q", "0.00%"),
                        Pair.of("R", "0.00%"),
                        Pair.of("S", "0.00%"),
                        Pair.of("X", "0.00%"),
                        Pair.of("Y", "0.00%"),
                        Pair.of("Z", "0.00%"),
                        Pair.of("AA", "0.00%"),
                        Pair.of("AF", "0.00%"),
                        Pair.of("AG", "0.00%"),
                        Pair.of("AH", "0.00%"),
                        Pair.of("AO", "0.00%"),
                        Pair.of("AP", "0.00%"),
                        Pair.of("AQ", "0.00%"),
                        Pair.of("AR", "0.00%"),
                        Pair.of("AW", "0.00%"),
                        Pair.of("AX", "0.00%"),
                        Pair.of("AY", "0.00%"),
                        Pair.of("BD", "0.00%"),
                        Pair.of("BE", "0.00%"),
                        Pair.of("BF", "0.00%"),
                        Pair.of("BG", "0.00%"),
                        Pair.of("BM", "0.00%"),
                        Pair.of("BN", "0.00%"),
                        Pair.of("BO", "0.00%"),
                        Pair.of("BP", "0.00%")
                );

        doSendFeishuSheet(dateStrList, sheetToken, sheetId, rowNum, rows, 3, styles, null, null);
    }

    public List<IntermediateIndicatorsExport> intermediateIndicatorsData(String dateStr) {
        List<IntermediateIndicatorsExport> result = buildIntermediateIndicatorsData(dateStr);
        Map<String, IntermediateIndicatorsExport> resultMap = result.stream().collect(Collectors.toMap(
                IntermediateIndicatorsExport::getType, o -> o));
        List<String> small = Arrays.asList("gh_084a485e859a", "gh_183d80deffb8", "gh_1b27dd1beeca", "gh_29074b51f2b7",
                "gh_4568b5a7e2fe", "gh_5ff48e9fb9ef", "gh_6d9f36e3a7be", "gh_72bace6b3059", "gh_7b4a5f86d68c",
                "gh_9f8dc5b0c74e", "gh_b676b7ad9b74", "gh_ee78360d06f5", "gh_f25b5fb01977", "gh_f902cea89e48");
        Long dateStart = DateUtils.getStartOfDay(dateStr, "yyyyMMdd");
        Long dateEnd = DateUtils.getEndOfDay(dateStr, "yyyyMMdd");
        long timestamp = DateUtils.dateStrToTimestamp(dateStr, "yyyyMMdd");
        String dateStrS = DateUtils.timestampToYMDStr(timestamp, "yyyy-MM-dd");
        List<AccountAvgInfo> accountAvgInfoList = accountAvgInfoRepository.getAllByUpdateTimeLessThanEqual(dateStrS);
        Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap = accountAvgInfoList.stream()
                .filter(o -> Objects.nonNull(o.getReadAvg()) && o.getReadAvg() > 0 && o.getFans() > 1000)
                .collect(Collectors.groupingBy(AccountAvgInfo::getGhId, Collectors.groupingBy(AccountAvgInfo::getUpdateTime,
                        Collectors.toMap(AccountAvgInfo::getPosition, o -> o))));
        List<String> ghIds = accountAvgInfoList.stream().map(AccountAvgInfo::getGhId).distinct().collect(Collectors.toList());
        List<Article> articleList = crawlerBaseMapper.getByGhIdInAndPublishTimestampLessThanAndTypeEquals(ghIds, dateEnd, ArticleTypeEnum.QUNFA.getVal());
        Map<String, Article> articleMap = articleList.stream().collect(Collectors.toMap(Article::getWxSn, o -> o));
        List<Article> todayPublish = articleList.stream().filter(o -> o.getPublishTimestamp() > dateStart).collect(Collectors.toList());
        if (CollectionUtils.isEmpty(todayPublish)) {
            return new ArrayList<>();
        }
        Map<String, List<Article>> hisPublishMap = articleList.stream().collect(Collectors.groupingBy(Article::getTitle));
        List<String> wxSnList = articleList.stream().map(Article::getWxSn).distinct().collect(Collectors.toList());
        List<ArticleDetailInfo> articleDetailInfoList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(wxSnList, 1000)) {
            articleDetailInfoList.addAll(crawlerBaseMapper.getAllByWxSnIn(partitions));
        }
        Map<String, List<ArticleDetailInfo>> articleDetailInfoMap = articleDetailInfoList.stream()
                .collect(Collectors.groupingBy(ArticleDetailInfo::getWxSn));
        String lessDateStr = DateUtils.getBeforeDayStr(dateStr, "yyyyMMdd", 7);
        List<PublishSortLog> publishSortLogList = publishSortLogRepository.findByDateStrGreaterThanEqual(lessDateStr);
        Map<String, Map<String, Map<Integer, List<PublishSortLog>>>> publishSortLogMap = publishSortLogList.stream()
                .collect(Collectors.groupingBy(PublishSortLog::getGhId,
                        Collectors.groupingBy(PublishSortLog::getDateStr, Collectors.groupingBy(PublishSortLog::getIndex))));
        List<DatastatSortStrategy> newSortStrategyExportList = getNewSortStrategyExportList(todayPublish,
                articleDetailInfoMap, accountAvgInfoIndexMap);

        List<Article> futurePublishList = articleRepository.getByPublishTimestampGreaterThanAndTypeEquals(dateEnd, ArticleTypeEnum.QUNFA.getVal());
        Map<String, List<Article>> futurePublishMap = futurePublishList.stream().collect(Collectors.groupingBy(Article::getTitle));

        List<ArticlePoolPromotionSource> promotionSourceList = articlePoolPromotionSourceRepository.getByStatusAndDeleted(1, 0);
        Map<String, ArticlePoolPromotionSource> promotionSourceMap = promotionSourceList.stream()
                .collect(Collectors.toMap(ArticlePoolPromotionSource::getTitle, Function.identity(), (a, b) -> a));

        Map<String, List<String>> titleTypeMap = new HashMap<>();
        Map<String, Integer> scoreHisPublishTimeMap = new HashMap<>();
        Map<String, Map<Integer, List<String>>> titleTypePoolMap = new HashMap<>();
        Map<String, Set<String>> wxsnHisDistinctSetMap = new HashMap<>();
        Map<String, List<String>> fansAccountTypeMap = new HashMap<>();
        Map<String, List<String>> futurePromotionDistinctMap = new HashMap<>();
        for (DatastatSortStrategy data : newSortStrategyExportList) {
            String type = getArticleType(data, small);
            Article article = articleMap.get(data.getWxSn());
            if (!checkIsAigcPublish(article, publishSortLogMap)) {
                continue;
            }
            IntermediateIndicatorsExport item = resultMap.get(type);
            List<Article> list = hisPublishMap.get(data.getTitle());
            Integer poolLevel = getArticlePoolLevel(data.getGhId(), list, small);
            list = list.stream().filter(publish -> publish.getPublishTimestamp() < (article.getPublishTimestamp() - 3600 * 8))
                    .collect(Collectors.toList());
            // L1层仅统计历史发布在3-8位置文章
            if (poolLevel > 1 && "L1".equals(item.getType())) {
                continue;
            }
            List<String> titles = titleTypeMap.computeIfAbsent(type, k -> new ArrayList<>());
            Map<Integer, List<String>> titlePoolMap = titleTypePoolMap.computeIfAbsent(type, k -> new HashMap<>());
            List<String> poolTitles = titlePoolMap.computeIfAbsent(poolLevel, k -> new ArrayList<>());

            AccountAvgInfo accountAvgInfo = getAccountAvgInfo(accountAvgInfoIndexMap, article.getGhId(),
                    article.getPublishTimestamp(), article.getItemIndex());
//            // L4层仅统计 稳定-大和稳定
//            if ("L4".equals(item.getType()) && (Objects.isNull(accountAvgInfo)
//                    || !StringUtils.hasText(accountAvgInfo.getAccountStatus())
//                    || !accountAvgInfo.getAccountStatus().contains("稳定"))) {
//                continue;
//            }
            // 发布情况
            setPublishSituation(item, type, titleTypeMap, titleTypePoolMap, poolLevel, article, fansAccountTypeMap,
                    accountAvgInfo);
            // 发布表现
            setPublishPerformance(item, data, publishSortLogMap);
            // 发布依赖表现
            setPublishSourcePerformance(item, data, article, accountAvgInfoIndexMap, articleDetailInfoMap, publishSortLogMap,
                    type, scoreHisPublishTimeMap, wxsnHisDistinctSetMap, list, poolLevel, small, hisPublishMap);
            // 发布未来表现
            setPublishFuturePerformance(item, data, poolLevel, promotionSourceMap, futurePublishMap, small, futurePromotionDistinctMap);

            titles.add(data.getTitle());
            poolTitles.add(data.getTitle());
        }

        return result;
    }

    private boolean checkIsAigcPublish(Article article,
                                       Map<String, Map<String, Map<Integer, List<PublishSortLog>>>> publishSortLogMap) {
        Map<String, Map<Integer, List<PublishSortLog>>> dateSortMap = publishSortLogMap.get(article.getGhId());
        if (Objects.nonNull(dateSortMap)) {
            for (String dateStr : dateSortMap.keySet()) {
                Map<Integer, List<PublishSortLog>> indexMap = dateSortMap.get(dateStr);
                if (Objects.nonNull(indexMap)) {
                    List<PublishSortLog> logs = indexMap.get(article.getItemIndex());
                    if (CollectionUtil.isNotEmpty(logs)) {
                        for (PublishSortLog log : logs) {
                            if (log.getTitle().equals(article.getTitle())) {
                                return true;
                            }
                        }
                    }
                }
            }
        }
        return false;
    }

    private AccountAvgInfo getAccountAvgInfo(Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap,
                                             String ghId, Long updateTime, Integer itemIndex) {
        Map<String, Map<String, AccountAvgInfo>> dateAvgMap = accountAvgInfoIndexMap.get(ghId);
        String hisPublishDate = DateUtils.timestampToYMDStr(updateTime, "yyyy-MM-dd");
        AccountAvgInfo avgInfo = null;
        if (Objects.nonNull(dateAvgMap)) {
            List<String> avgMapDateList = new ArrayList<>(dateAvgMap.keySet());
            hisPublishDate = DateUtils.findNearestDate(avgMapDateList, hisPublishDate, "yyyy-MM-dd");
            Map<String, AccountAvgInfo> accountAvgInfoMap = dateAvgMap.get(hisPublishDate);
            if (Objects.nonNull(accountAvgInfoMap)) {
                avgInfo = accountAvgInfoMap.get(itemIndex.toString());
            }
        }
        return avgInfo;
    }

    private Map<String, AccountAvgInfo> getDateAccountAvgInfo(Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap,
                                                              String ghId, Long updateTime, Integer itemIndex) {
        Map<String, Map<String, AccountAvgInfo>> dateAvgMap = accountAvgInfoIndexMap.get(ghId);
        String hisPublishDate = DateUtils.timestampToYMDStr(updateTime, "yyyy-MM-dd");
        if (Objects.nonNull(dateAvgMap)) {
            List<String> avgMapDateList = new ArrayList<>(dateAvgMap.keySet());
            hisPublishDate = DateUtils.findNearestDate(avgMapDateList, hisPublishDate, "yyyy-MM-dd");
            Map<String, AccountAvgInfo> accountAvgInfoMap = dateAvgMap.get(hisPublishDate);
            if (Objects.nonNull(accountAvgInfoMap)) {
                return accountAvgInfoMap;
            }
        }
        return new HashMap<>();
    }

    private void setPublishFuturePerformance(IntermediateIndicatorsExport item, DatastatSortStrategy data, Integer poolLevel,
                                             Map<String, ArticlePoolPromotionSource> promotionSourceMap,
                                             Map<String, List<Article>> futurePublishMap,
                                             List<String> small,
                                             Map<String, List<String>> futurePromotionDistinctMap) {
        int futurePoolLevel = getPromotionPoolLevel(data.getGhId(), data, promotionSourceMap, small);
        if (futurePoolLevel > poolLevel) {
            if (!futurePromotionDistinctMap.containsKey(item.getType())
                    || !futurePromotionDistinctMap.get(item.getType()).contains(data.getTitle())) {
                if (futurePoolLevel == 2) {
                    item.setPromotionCountL2(item.getPromotionCountL2() + 1);
                    item.setPromotionRateL2((item.getPromotionCountL2() * 1.0) / item.getActualArticleReleaseCount());
                } else if (futurePoolLevel == 3) {
                    item.setPromotionCountL3(item.getPromotionCountL3() + 1);
                    item.setPromotionRateL3((item.getPromotionCountL3() * 1.0) / item.getActualArticleReleaseCount());
                } else if (futurePoolLevel == 4) {
                    item.setPromotionCountL4(item.getPromotionCountL4() + 1);
                    item.setPromotionRateL4((item.getPromotionCountL4() * 1.0) / item.getActualArticleReleaseCount());
                }
                futurePromotionDistinctMap.computeIfAbsent(item.getType(), k -> new ArrayList<>()).add(data.getTitle());
            }
        }
        List<Article> futurePublishList = futurePublishMap.get(data.getTitle());
        if (CollectionUtils.isEmpty(futurePublishList)) {
            return;
        }
        if (Objects.isNull(data.getSecondFirstLevel())) {
            return;
        }
        item.setT1DayFirstLayerUV(item.getT1DayFirstLayerUV() + data.getSecondFirstLevel());
        item.setT1DayT0FissionUV(item.getT1DayT0FissionUV() + data.getSecondFission0());
        item.setT2DayFirstLayerUV(item.getT2DayFirstLayerUV() + data.getThirdFirstLevel());
        item.setT2DayT0FissionUV(item.getT2DayT0FissionUV() + data.getThirdFission0());
        item.setT1DayAccountArticleRelevanceAvg(item.getAccountArticleRelevanceAvg());
        item.setT2DayAccountArticleRelevanceAvg(item.getAccountArticleRelevanceAvg());
        item.setT1DayViewBase(item.getViewBase());
        item.setT2DayViewBase(item.getViewBase());
        item.setT1DayViewCount(item.getViewCount());
        item.setT2DayViewCount(item.getViewCount());
        double t1DayAverageViewToBaseRatio = item.getT1DayAverageViewToBaseRatio();
        if (data.getViewCount() > 0 && Objects.nonNull(data.getAvgViewCount()) && data.getAvgViewCount() > 0) {
            double t1DayViewToBaseRatio = data.getViewCount() / data.getAvgViewCount();
            t1DayAverageViewToBaseRatio = (t1DayAverageViewToBaseRatio * (item.getActualArticleReleaseCount() - 1)
                    + t1DayViewToBaseRatio) / item.getActualArticleReleaseCount();
        }
        item.setT1DayAverageViewToBaseRatio(t1DayAverageViewToBaseRatio);
        double t1DayAverageMiniAppOpenRate = item.getT1DayAverageMiniAppOpenRate();
        if (data.getSecondFirstLevel() > 0 && Objects.nonNull(data.getAvgViewCount()) && data.getAvgViewCount() > 0) {
            double t1DayMiniAppOpenRate = data.getSecondFirstLevel() / data.getAvgViewCount();
            t1DayAverageMiniAppOpenRate = (t1DayAverageMiniAppOpenRate * (item.getActualArticleReleaseCount() - 1)
                    + t1DayMiniAppOpenRate) / item.getActualArticleReleaseCount();
        }
        item.setT1DayAverageMiniAppOpenRate(t1DayAverageMiniAppOpenRate);
        double t1DayAverageT0FissionRate = item.getT1DayAverageT0FissionRate();
        if (data.getSecondFission0() > 0 && data.getSecondFirstLevel() > 0) {
            double t1DayT0FissionRate = data.getSecondFission0() / (double) data.getSecondFirstLevel();
            t1DayAverageT0FissionRate = (t1DayAverageT0FissionRate * (item.getActualArticleReleaseCount() - 1)
                    + t1DayT0FissionRate) / item.getActualArticleReleaseCount();
        }
        item.setT1DayAverageT0FissionRate(t1DayAverageT0FissionRate);
        double t1DayAverageFirstLayerFissionToViewBaseRatio = item.getT1DayAverageFirstLayerFissionToViewBaseRatio();
        if (data.getSecondFission0() > 0 && Objects.nonNull(data.getAvgViewCount()) && data.getAvgViewCount() > 0) {
            double t1DayFirstLayerFissionToViewBaseRatio = data.getSecondFission0() / data.getAvgViewCount();
            t1DayAverageFirstLayerFissionToViewBaseRatio = (t1DayAverageFirstLayerFissionToViewBaseRatio * (item.getActualArticleReleaseCount() - 1)
                    + t1DayFirstLayerFissionToViewBaseRatio) / item.getActualArticleReleaseCount();
        }
        item.setT1DayAverageFirstLayerFissionToViewBaseRatio(t1DayAverageFirstLayerFissionToViewBaseRatio);
        double t2DayAverageViewToBaseRatio = item.getT2DayAverageViewToBaseRatio();
        if (data.getViewCount() > 0 && Objects.nonNull(data.getAvgViewCount()) && data.getAvgViewCount() > 0) {
            double t2DayViewToBaseRatio = data.getViewCount() / data.getAvgViewCount();
            t2DayAverageViewToBaseRatio = (t2DayAverageViewToBaseRatio * (item.getActualArticleReleaseCount() - 1)
                    + t2DayViewToBaseRatio) / item.getActualArticleReleaseCount();
        }
        item.setT2DayAverageViewToBaseRatio(t2DayAverageViewToBaseRatio);
        double t2DayAverageMiniAppOpenRate = item.getT2DayAverageMiniAppOpenRate();
        if (data.getThirdFirstLevel() > 0 && Objects.nonNull(data.getAvgViewCount()) && data.getAvgViewCount() > 0) {
            double t2DayMiniAppOpenRate = data.getThirdFirstLevel() / data.getAvgViewCount();
            t2DayAverageMiniAppOpenRate = (t2DayAverageMiniAppOpenRate * (item.getActualArticleReleaseCount() - 1)
                    + t2DayMiniAppOpenRate) / item.getActualArticleReleaseCount();
        }
        item.setT2DayAverageMiniAppOpenRate(t2DayAverageMiniAppOpenRate);
        double t2DayAverageT0FissionRate = item.getT2DayAverageT0FissionRate();
        if (data.getThirdFission0() > 0 && data.getSecondFirstLevel() > 0) {
            double t2DayT0FissionRate = data.getThirdFission0() / (double) data.getSecondFirstLevel();
            t2DayAverageT0FissionRate = (t2DayAverageT0FissionRate * (item.getActualArticleReleaseCount() - 1)
                    + t2DayT0FissionRate) / item.getActualArticleReleaseCount();
        }
        item.setT2DayAverageT0FissionRate(t2DayAverageT0FissionRate);
        double t2DayAverageFirstLayerFissionToViewBaseRatio = item.getT2DayAverageFirstLayerFissionToViewBaseRatio();
        if (data.getThirdFission0() > 0 && Objects.nonNull(data.getAvgViewCount()) && data.getAvgViewCount() > 0) {
            double t2DayFirstLayerFissionToViewBaseRatio = data.getThirdFission0() / data.getAvgViewCount();
            t2DayAverageFirstLayerFissionToViewBaseRatio = (t2DayAverageFirstLayerFissionToViewBaseRatio * (item.getActualArticleReleaseCount() - 1)
                    + t2DayFirstLayerFissionToViewBaseRatio) / item.getActualArticleReleaseCount();
        }
        item.setT2DayAverageFirstLayerFissionToViewBaseRatio(t2DayAverageFirstLayerFissionToViewBaseRatio);

//        item.setT3DayViewCount(item.getT3DayViewCount());
//        item.setT3DayFirstLayerUV(item.getT3DayFirstLayerUV());
//        item.setT3DayT0FissionUV(item.getT3DayT0FissionUV());
//        item.setT3DayAccountArticleRelevanceAvg(item.getT3DayAccountArticleRelevanceAvg());
//        item.setT3DayAverageViewToBaseRatio(item.getT3DayAverageViewToBaseRatio());
//        item.setT3DayAverageMiniAppOpenRate(item.getT3DayAverageMiniAppOpenRate());
//        item.setT3DayAverageT0FissionRate(item.getT3DayAverageT0FissionRate());
//        item.setT3DayAverageFirstLayerFissionToViewBaseRatio(item.getT3DayAverageFirstLayerFissionToViewBaseRatio());
//        item.setT3DayViewBase(item.getT3DayViewBase());
//        item.setT3PlusDayViewCount(item.getT3PlusDayViewCount());
//        item.setT3PlusDayFirstLayerUV(item.getT3PlusDayFirstLayerUV());
//        item.setT3PlusDayT0FissionUV(item.getT3PlusDayT0FissionUV());
//        item.setT3PlusDayAccountArticleRelevanceAvg(item.getT3PlusDayAccountArticleRelevanceAvg());
//        item.setT3PlusDayAverageViewToBaseRatio(item.getT3PlusDayAverageViewToBaseRatio());
//        item.setT3PlusDayAverageMiniAppOpenRate(item.getT3PlusDayAverageMiniAppOpenRate());
//        item.setT3PlusDayAverageT0FissionRate(item.getT3PlusDayAverageT0FissionRate());
//        item.setT3PlusDayAverageFirstLayerFissionToViewBaseRatio(item.getT3PlusDayAverageFirstLayerFissionToViewBaseRatio());
//        item.setT3PlusDayViewBase(item.getT3PlusDayViewBase());
    }

    private int getPromotionPoolLevel(String ghId, DatastatSortStrategy data,
                                      Map<String, ArticlePoolPromotionSource> promotionSourceMap,
                                      List<String> small) {
        ArticlePoolPromotionSource promotionSource = promotionSourceMap.get(data.getTitle());
        if (Objects.isNull(promotionSource)) {
            return 1;
        }
        if (data.getPublishTimestamp() > (promotionSource.getCreateTimestamp() / 1000)) {
            return 1;
        }
        if (promotionSource.getLevel().equals(ContentPoolEnum.autoArticlePoolLevel1.getContentPool())) {
            if (small.contains(ghId)) {
                return 3;
            } else {
                return 4;
            }
        } else if (promotionSource.getLevel().equals(ContentPoolEnum.autoArticlePoolLevel3.getContentPool())) {
            return 2;
        } else {
            return 1;
        }
    }

    private List<DatastatSortStrategy> getNewSortStrategyExportList(List<Article> todayPublish,
                                                                    Map<String, List<ArticleDetailInfo>> articleDetailInfoMap,
                                                                    Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap) {
        List<DatastatSortStrategy> result = new ArrayList<>();
        for (Article article : todayPublish) {
            DatastatSortStrategy obj = new DatastatSortStrategy();
            List<ArticleDetailInfo> articleDetailInfos = articleDetailInfoMap.get(article.getWxSn());
            setObjArticleDetailInfo(article, obj, articleDetailInfos);
            Map<String, AccountAvgInfo> indexAvgInfoMap = getDateAccountAvgInfo(accountAvgInfoIndexMap, article.getGhId(),
                    article.getPublishTimestamp(), article.getItemIndex());
            String date = DateUtils.timestampToYMDStr(article.getPublishTimestamp(), "yyyyMMdd");
            setObjBaseInfo(article, obj, date);
            setObjAvgInfo(article, obj, indexAvgInfoMap);
            result.add(obj);
        }
        return result;
    }

    private void setPublishSourcePerformance(IntermediateIndicatorsExport item,
                                             DatastatSortStrategy data,
                                             Article article,
                                             Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoIndexMap,
                                             Map<String, List<ArticleDetailInfo>> articleDetailInfoMap,
                                             Map<String, Map<String, Map<Integer, List<PublishSortLog>>>> publishSortLogMap,
                                             String type,
                                             Map<String, Integer> scoreHisPublishTimeMap,
                                             Map<String, Set<String>> wxsnHisDistinctSetMap,
                                             List<Article> hisPublish,
                                             Integer poolLevel,
                                             List<String> small,
                                             Map<String, List<Article>> hisPublishMap) {
        Long hisMinDate = hisPublish.stream().mapToLong(Article::getPublishTimestamp).min().orElse(0);
        int scorePublishTime = scoreHisPublishTimeMap.computeIfAbsent(type, k -> 0);
        Set<String> wxsnHisDistinctSet = wxsnHisDistinctSetMap.computeIfAbsent(type, k -> new HashSet<>());
        for (Article publish : hisPublish) {
            if (poolLevel == 1) {
                List<Article> list = hisPublishMap.get(publish.getTitle());
                list = list.stream().filter(o -> o.getPublishTimestamp() < (publish.getPublishTimestamp() - 3600 * 8))
                        .collect(Collectors.toList());
                Integer hisPublishPoolLevel = getArticlePoolLevel(publish.getGhId(), list, small);
                if (hisPublishPoolLevel > poolLevel) {
                    continue;
                }
            }
            AccountAvgInfo avgInfo = getAccountAvgInfo(accountAvgInfoIndexMap, publish.getGhId(),
                    publish.getPublishTimestamp(), publish.getItemIndex());
            if (wxsnHisDistinctSet.contains(publish.getWxSn())) {
                continue;
            }
            wxsnHisDistinctSet.add(publish.getWxSn());
            item.setTotalArticleReleaseCountNonInfinite(item.getTotalArticleReleaseCountNonInfinite() + 1);
            item.setRedundantViewCount(item.getRedundantViewCount() + publish.getShowViewCount());
            if (Objects.nonNull(avgInfo)) {
                item.setRedundantViewBase(item.getRedundantViewBase() + avgInfo.getReadAvg());
            }
            if (item.getRedundantViewBase() > 0 && item.getRedundantViewCount() > 0) {
                item.setAverageViewToBaseRatio(item.getRedundantViewCount() / (double) item.getRedundantViewBase());
            }
            List<ArticleDetailInfo> articleDetailInfos = articleDetailInfoMap.get(publish.getWxSn());

            if (CollectionUtils.isEmpty(articleDetailInfos)) {
                continue;
            }
            int sumFirstLevel = 0;
            int sumFission0 = 0;
            Date minDate = articleDetailInfos.stream().map(ArticleDetailInfo::getRecallDt).min(Date::compareTo).orElse(new Date());
            for (ArticleDetailInfo articleDetailInfo : articleDetailInfos) {
                if (articleDetailInfo.getRecallDt().equals(minDate)) {
                    sumFirstLevel += Optional.ofNullable(articleDetailInfo.getFirstLevel()).orElse(0);
                    sumFission0 += Optional.ofNullable(articleDetailInfo.getFission0()).orElse(0);
                }
            }
            item.setRedundantFirstLayerUV(item.getRedundantFirstLayerUV() + sumFirstLevel);
            item.setRedundantT0FissionUV(item.getRedundantT0FissionUV() + sumFission0);
            double averageMiniAppOpenRate = item.getAverageMiniAppOpenRate();
            if (item.getRedundantFirstLayerUV() > 0 && item.getRedundantViewCount() > 0) {
                double miniAppOpenRate = item.getRedundantFirstLayerUV() / (double) item.getRedundantViewCount();
                averageMiniAppOpenRate = (averageMiniAppOpenRate * (item.getActualArticleReleaseCount() - 1)
                        + miniAppOpenRate) / item.getActualArticleReleaseCount();
            }
            item.setAverageMiniAppOpenRate(averageMiniAppOpenRate);
            double averageT0FissionRate = item.getAverageT0FissionRate();
            if (item.getRedundantT0FissionUV() > 0 && item.getRedundantFirstLayerUV() > 0) {
                double t0FissionRate = item.getRedundantT0FissionUV() / (double) item.getRedundantFirstLayerUV();
                averageT0FissionRate = (averageT0FissionRate * (item.getActualArticleReleaseCount() - 1)
                        + t0FissionRate) / item.getActualArticleReleaseCount();
            }
            item.setAverageT0FissionRate(averageT0FissionRate);
            double averageFirstLayerFissionToViewBaseRatio = item.getAverageFirstLayerFissionToViewBaseRatio();
            if (item.getRedundantViewBase() > 0 && item.getRedundantT0FissionUV() > 0) {
                double firstLayerFissionToViewBaseRatio = item.getRedundantT0FissionUV() / (double) item.getRedundantViewBase();
                averageFirstLayerFissionToViewBaseRatio = (averageFirstLayerFissionToViewBaseRatio *
                        (item.getActualArticleReleaseCount() - 1) + firstLayerFissionToViewBaseRatio) / item.getActualArticleReleaseCount();
            }
            item.setAverageFirstLayerFissionToViewBaseRatio(averageFirstLayerFissionToViewBaseRatio);
            Map<String, Map<Integer, List<PublishSortLog>>> dateSortMap = publishSortLogMap.get(publish.getGhId());
            if (Objects.nonNull(dateSortMap)) {
                String publishDateStr = DateUtils.timestampToYMDStr(publish.getPublishTimestamp(), "yyyyMMdd");
                Map<Integer, List<PublishSortLog>> indexMap = dateSortMap.get(publishDateStr);
                if (Objects.nonNull(indexMap)) {
                    List<PublishSortLog> logs = indexMap.get(publish.getItemIndex());
                    if (CollectionUtil.isNotEmpty(logs)) {
                        for (PublishSortLog log : logs) {
                            if (log.getTitle().equals(data.getTitle())) {
                                double scoreAvg = item.getRedundantAccountArticleRelevanceAvg();
                                double score = 0.0;
                                if (Objects.nonNull(log.getScore())) {
                                    JSONObject scoreMap = JSONObject.parseObject(log.getScoreMap());
                                    if (Objects.nonNull(scoreMap) && scoreMap.containsKey("SimilarityStrategy")) {
                                        score = scoreMap.getDoubleValue("SimilarityStrategy");
                                    }
                                }
                                scorePublishTime++;
                                scoreAvg = (scoreAvg * (scorePublishTime - 1) + score) / scorePublishTime;
                                item.setRedundantAccountArticleRelevanceAvg(scoreAvg);
                                break;
                            }
                        }
                    }
                }
            }
        }
        if (hisMinDate > 0) {
            double firstExplorationIntervalAvg = Double.isNaN(item.getFirstExplorationIntervalAvg()) ? 0.0 : item.getFirstExplorationIntervalAvg();
            double explorationInterval = (article.getPublishTimestamp() - hisMinDate) / 86400.0;
            firstExplorationIntervalAvg = (firstExplorationIntervalAvg * (item.getActualArticleReleaseCount() - 1)
                    + explorationInterval) / item.getActualArticleReleaseCount();
            item.setFirstExplorationIntervalAvg(firstExplorationIntervalAvg);
        }
        scoreHisPublishTimeMap.put(type, scorePublishTime);
    }

    private void setPublishPerformance(IntermediateIndicatorsExport item, DatastatSortStrategy data,
                                       Map<String, Map<String, Map<Integer, List<PublishSortLog>>>> publishSortLogMap) {
        if (Objects.isNull(data.getFirstLevel())) {
            return;
        }
        item.setViewCount(item.getViewCount() + data.getViewCount());
        item.setFirstLayerUV(item.getFirstLayerUV() + data.getFirstLevel());
        item.setT0FissionUV(item.getT0FissionUV() + data.getFission0());
        if (Objects.nonNull(data.getAvgViewCount())) {
            item.setViewBase(item.getViewBase() + data.getAvgViewCount());
        }
        if (item.getViewBase() > 0 && item.getViewCount() > 0) {
            item.setViewToBaseRatio(item.getViewCount() / (double) item.getViewBase());
        }
        if (item.getFirstLayerUV() > 0 && item.getViewCount() > 0) {
            item.setMiniAppOpenRate(item.getFirstLayerUV() / (double) item.getViewCount());
        }
        if (item.getFirstLayerUV() > 0 && item.getT0FissionUV() > 0) {
            item.setT0FissionRate(item.getT0FissionUV() / (double) item.getFirstLayerUV());
            item.setT0FissionRateAgain(item.getT0FissionUV() / (double) item.getFirstLayerUV());
        }
        item.setT0FissionCount(item.getT0FissionCount() + data.getFission0());
        item.setT1FissionCount(item.getT1FissionCount() + data.getFission1());
        item.setT2FissionCount(item.getT2FissionCount() + data.getFission2());
        if (item.getT0FissionCount() > 0 && item.getViewBase() > 0) {
            item.setFirstLayerFissionToViewBaseRatio(item.getT0FissionCount() / (double) item.getViewBase());
        }
        if (item.getT0FissionCount() + item.getT1FissionCount() > 0 && item.getFirstLayerUV() > 0) {
            item.setT1CumulativeFissionRate((item.getT0FissionCount() + item.getT1FissionCount()) / (double) item.getFirstLayerUV());
        }
        if (item.getT0FissionCount() + item.getT1FissionCount() + item.getT2FissionCount() > 0 && item.getViewBase() > 0) {
            item.setT2CumulativeFissionRate((item.getT0FissionCount() + item.getT1FissionCount() + item.getT2FissionCount()) / (double) item.getFirstLayerUV());
        }
        Map<String, Map<Integer, List<PublishSortLog>>> dateSortMap = publishSortLogMap.get(data.getGhId());
        if (Objects.nonNull(dateSortMap)) {
            Map<Integer, List<PublishSortLog>> indexMap = dateSortMap.get(item.getDateStr());
            if (Objects.nonNull(indexMap)) {
                List<PublishSortLog> logs = indexMap.get(data.getPosition());
                if (CollectionUtil.isNotEmpty(logs)) {
                    for (PublishSortLog log : logs) {
                        if (log.getTitle().equals(data.getTitle())) {
                            double scoreAvg = item.getAccountArticleRelevanceAvg();
                            double score = 0.0;
                            if (Objects.nonNull(log.getScore())) {
                                JSONObject scoreMap = JSONObject.parseObject(log.getScoreMap());
                                if (Objects.nonNull(scoreMap) && scoreMap.containsKey("SimilarityStrategy")) {
                                    score = scoreMap.getDoubleValue("SimilarityStrategy");
                                }
                            }
                            scoreAvg = (scoreAvg * (item.getActualArticleReleaseCount() - 1) + score) / item.getActualArticleReleaseCount();
                            item.setAccountArticleRelevanceAvg(scoreAvg);
                            break;
                        }
                    }
                }
            }
        }
    }

    private void setPublishSituation(IntermediateIndicatorsExport item, String type, Map<String, List<String>> titleTypeMap,
                                     Map<String, Map<Integer, List<String>>> titleTypePoolMap, Integer poolLevel,
                                     Article article, Map<String, List<String>> fansAccountTypeMap,
                                     AccountAvgInfo accountAvgInfo) {
        item.setArticleReleaseSlot(item.getArticleReleaseSlot() + 1);
        item.setActualArticleReleaseCount(item.getActualArticleReleaseCount() + 1);
        if (titleTypeMap.containsKey(type) && !titleTypeMap.get(type).contains(article.getTitle())) {
            item.setDistinctArticleReleaseCount(item.getDistinctArticleReleaseCount() + 1);
        }
        item.setDistinctArticleReleaseRatio(item.getDistinctArticleReleaseCount() / (double) item.getActualArticleReleaseCount());
        List<String> ghIds = fansAccountTypeMap.computeIfAbsent(type, k -> new ArrayList<>());
        if (!ghIds.contains(article.getGhId())) {
            ghIds.add(article.getGhId());
            if (Objects.nonNull(accountAvgInfo)) {
                item.setFansCount(item.getFansCount() + accountAvgInfo.getFans());
            }
        }
        if (4 == poolLevel) {
            item.setActualReleaseCountL4(item.getActualReleaseCountL4() + 1);
        } else if (3 == poolLevel) {
            item.setActualReleaseCountL3(item.getActualReleaseCountL3() + 1);
        } else if (2 == poolLevel) {
            item.setActualReleaseCountL2(item.getActualReleaseCountL2() + 1);
        } else {
            item.setActualReleaseCountL1(item.getActualReleaseCountL1() + 1);
        }
        if (titleTypePoolMap.containsKey(type)
                && titleTypePoolMap.get(type).containsKey(poolLevel)
                && !titleTypePoolMap.get(type).get(poolLevel).contains(article.getTitle())) {
            if (4 == poolLevel) {
                item.setDistinctReleaseCountL4(item.getDistinctReleaseCountL4() + 1);
            } else if (3 == poolLevel) {
                item.setDistinctReleaseCountL3(item.getDistinctReleaseCountL3() + 1);
            } else if (2 == poolLevel) {
                item.setDistinctReleaseCountL2(item.getDistinctReleaseCountL2() + 1);
            } else {
                item.setDistinctReleaseCountL1(item.getDistinctReleaseCountL1() + 1);
            }
        }
        if (item.getActualReleaseCountL1() > 0 && item.getDistinctReleaseCountL1() > 0) {
            item.setDistinctToActualRatioL1(item.getDistinctReleaseCountL1() / (double) item.getActualReleaseCountL1());
        }
        if (item.getActualReleaseCountL2() > 0 && item.getDistinctReleaseCountL2() > 0) {
            item.setDistinctToActualRatioL2(item.getDistinctReleaseCountL2() / (double) item.getActualReleaseCountL2());
        }
        if (item.getActualReleaseCountL3() > 0 && item.getDistinctReleaseCountL3() > 0) {
            item.setDistinctToActualRatioL3(item.getDistinctReleaseCountL3() / (double) item.getActualReleaseCountL3());
        }
        if (item.getActualReleaseCountL4() > 0 && item.getDistinctReleaseCountL4() > 0) {
            item.setDistinctToActualRatioL4(item.getDistinctReleaseCountL4() / (double) item.getActualReleaseCountL4());
        }
    }

    private Integer getArticlePoolLevel(String ghId, List<Article> list, List<String> small) {
        int minPosition = list.stream().mapToInt(Article::getItemIndex).min().orElse(8);
        if (minPosition == 1) {
            if (small.contains(ghId)) {
                return 3;
            } else {
                return 4;
            }
        } else if (minPosition == 2) {
            return 2;
        } else {
            return 1;
        }
    }

    private String getArticleType(DatastatSortStrategy data, List<String> small) {
        if (data.getPosition() == 1) {
            if (small.contains(data.getGhId())) {
                return "L3";
            } else {
                return "L4";
            }
        } else if (data.getPosition() == 2) {
            return "L2";
        } else {
            return "L1";
        }
    }

    private List<IntermediateIndicatorsExport> buildIntermediateIndicatorsData(String dateStr) {
        List<IntermediateIndicatorsExport> result = new ArrayList<>();
        List<String> typeList = Arrays.asList("L4", "L3", "L2", "L1");
        for (String type : typeList) {
            IntermediateIndicatorsExport item = new IntermediateIndicatorsExport();
            item.setDateStr(dateStr);
            item.setType(type);
            result.add(item);
        }
        return result;
    }

    @XxlJob("scheduleExportFirstContentScore")
    public ReturnT<String> scheduleExportFirstContentScore(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 3);
        exportFeishuFirstContentScore(dateStrList, dailyDetailSheetToken, "XBFd16");
        return ReturnT.SUCCESS;
    }

    public void firstContentScoreExport(String beginDate, String endDate) {
        List<String> dateStrList = DateUtils.getBeforeDays(beginDate, endDate, 3);
        exportFeishuFirstContentScore(dateStrList, dailyDetailSheetToken, "XBFd16");
    }

    private void exportFeishuFirstContentScore(List<String> dateStrList, String sheetToken, String sheetId) {
        List<FirstContentScoreExport> scoreDataList = firstContentScoreData(dateStrList);
        if (CollectionUtil.isEmpty(scoreDataList)) {
            return;
        }
        int rowNum = scoreDataList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = FirstContentScoreExport.class.getDeclaredFields();
        for (FirstContentScoreExport datum : scoreDataList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("H", "#,##0.00"),
                        Pair.of("I", "#,##0.00"),
                        Pair.of("J", "#,##0.00"),
                        Pair.of("K", "#,##0.00"),
                        Pair.of("L", "#,##0.00"),
                        Pair.of("M", "#,##0.00"),
                        Pair.of("N", "#,##0.00"),
                        Pair.of("O", "#,##0.00"),
                        Pair.of("P", "#,##0.00"),
                        Pair.of("Q", "#,##0.00"),
                        Pair.of("R", "#,##0.00"),
                        Pair.of("S", "#,##0.00"),
                        Pair.of("T", "#,##0.00"),
                        Pair.of("W", "#,##0.00")
                );

        doSendFeishuSheet(dateStrList, sheetToken, sheetId, rowNum, rows, 2, styles, null, null);
    }

    private List<FirstContentScoreExport> firstContentScoreData(List<String> dateStrList) {
        List<FirstContentScoreExport> result = new ArrayList<>();
        List<PublishSortLog> sortLogList = publishSortLogRepository.findByDateStrIn(dateStrList);
        sortLogList = sortLogList.stream().filter(o -> o.getIndex() == 1 || o.getIndex() == 2).collect(Collectors.toList());
        sortLogList.sort(Comparator.comparing(PublishSortLog::getGhId).thenComparing(PublishSortLog::getDateStr));
        List<String> ghIds = sortLogList.stream().map(PublishSortLog::getGhId).distinct().collect(Collectors.toList());
        long minTimestamp = DateUtils.dateStrToTimestamp(dateStrList.get(0), "yyyyMMdd");
        List<Article> articleList = articleRepository.getByGhIdInAndPublishTimestampGreaterThanAndTypeEquals(ghIds, minTimestamp, ArticleTypeEnum.QUNFA.getVal());
        articleList = articleList.stream().filter(o -> o.getItemIndex() == 1 || o.getItemIndex() == 2).collect(Collectors.toList());
        Map<String, Map<String, Map<Integer, Article>>> articleMap = articleList.stream().collect(
                Collectors.groupingBy(Article::getGhId, Collectors.groupingBy(o -> DateUtils.timestampToYMDStr(o.getPublishTimestamp(), "yyyyMMdd"),
                        Collectors.toMap(Article::getItemIndex, o -> o,
                                (existing, replacement) -> replacement))));
        List<String> titleList = articleList.stream().map(Article::getTitle).distinct().collect(Collectors.toList());
        List<PublishContentDTO> hisPublishList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(new ArrayList<>(titleList), 100)) {
            hisPublishList.addAll(publishContentMapper.getHisPublishByTitles(partitions));
        }
        Map<String, List<PublishContentDTO>> hisPublishMap = hisPublishList.stream().collect(Collectors.groupingBy(PublishContentDTO::getTitle));
        String ymd = DateUtils.timestampToYMDStr(minTimestamp - 86400 * 7, "yyyy-MM-dd");
        List<AccountAvgInfo> accountAvgInfoList = accountAvgInfoRepository.getAllByUpdateTimeGreaterThanEqual(ymd);
        Map<String, Map<String, Map<String, AccountAvgInfo>>> accountAvgInfoMap = accountAvgInfoList.stream()
                .filter(o -> Objects.equals(o.getPosition(), "1") || Objects.equals(o.getPosition(), "2"))
                .collect(Collectors.groupingBy(AccountAvgInfo::getGhId,
                        Collectors.groupingBy(AccountAvgInfo::getUpdateTime,
                                Collectors.toMap(AccountAvgInfo::getPosition, o -> o))));

        String title = "";
        List<DatastatScore> saveList = new ArrayList<>();
        for (PublishSortLog publishSortLog : sortLogList) {
            Map<String, Map<Integer, Article>> dateArticleMap = articleMap.get(publishSortLog.getGhId());
            if (Objects.isNull(dateArticleMap)) {
                continue;
            }
            Map<Integer, Article> indexMap = dateArticleMap.get(publishSortLog.getDateStr());
            if (Objects.isNull(indexMap)) {
                continue;
            }
            Article article = indexMap.get(publishSortLog.getIndex());
            if (Objects.isNull(article) || !publishSortLog.getTitle().equals(article.getTitle())) {
                continue;
            }
            if (publishSortLog.getTitle().equals(title)) {
                continue;
            }
            FirstContentScoreExport item = new FirstContentScoreExport();
            title = publishSortLog.getTitle();
            item.setDateStr(publishSortLog.getDateStr());
            item.setGhId(publishSortLog.getGhId());
            item.setAccountName(publishSortLog.getAccountName());
            item.setIndex(publishSortLog.getIndex());
            item.setTitle(publishSortLog.getTitle());
            if (StringUtils.hasText(publishSortLog.getCategory())) {
                List<String> categoryList = JSONArray.parseArray(publishSortLog.getCategory(), String.class);
                item.setCategory(categoryList.get(0));
            }
            item.setStrategy(publishSortLog.getStrategy());
            item.setScore(Double.valueOf(publishSortLog.getScore()));
            JSONObject scoreMap = JSONObject.parseObject(publishSortLog.getScoreMap());
            if (Objects.isNull(scoreMap)) {
                continue;
            }
            item.setHisFissionFansRateRateStrategy(scoreMap.getDoubleValue("HisFissionFansRateRateStrategy"));
            item.setHisFissionAvgReadRateRateStrategy(scoreMap.getDoubleValue("HisFissionAvgReadRateRateStrategy"));
            item.setPublishTimesStrategy(scoreMap.getDoubleValue("PublishTimesStrategy"));
            item.setViewCountRateCorrelationStrategy(scoreMap.getDoubleValue("ViewCountRateCorrelationStrategy"));
            item.setHisFissionAvgReadSumRateStrategy(scoreMap.getDoubleValue("HisFissionAvgReadSumRateStrategy"));
            item.setHisFissionAvgReadRateCorrelationRateStrategy(scoreMap.getDoubleValue("HisFissionAvgReadRateCorrelationRateStrategy"));
            item.setHisFissionFansSumRateStrategy(scoreMap.getDoubleValue("HisFissionFansSumRateStrategy"));
            item.setSimilarityStrategy(scoreMap.getDoubleValue("SimilarityStrategy"));
            item.setCategoryStrategy(scoreMap.getDoubleValue("CategoryStrategy"));
            item.setViewCountStrategy(scoreMap.getDoubleValue("ViewCountStrategy"));
            item.setViewCountRateStrategy(scoreMap.getDoubleValue("ViewCountRateStrategy"));
            item.setHisFissionDeWeightAvgReadSumRateStrategy(scoreMap.getDoubleValue("HisFissionDeWeightAvgReadSumRateStrategy"));
            item.setReadCount(article.getShowViewCount());
            Map<String, Map<String, AccountAvgInfo>> map = accountAvgInfoMap.get(article.getGhId());
            if (Objects.nonNull(map)) {
                List<String> avgMapDateList = new ArrayList<>(map.keySet());
                String publishDate = DateUtils.findNearestDate(avgMapDateList,
                        DateUtils.timestampToYMDStr(article.getPublishTimestamp(), "yyyy-MM-dd"), "yyyy-MM-dd");
                Map<String, AccountAvgInfo> avgIndexMap = map.get(publishDate);
                if (Objects.nonNull(avgIndexMap)) {
                    AccountAvgInfo accountAvgInfo = avgIndexMap.get(String.valueOf(publishSortLog.getIndex()));
                    if (Objects.nonNull(accountAvgInfo)) {
                        item.setReadAvg(accountAvgInfo.getReadAvg());
                        item.setReadAvgRate(article.getShowViewCount() / (double) accountAvgInfo.getReadAvg());
                    }
                }
            }
            List<PublishContentDTO> hisPublish = hisPublishMap.get(article.getTitle());
            if (CollectionUtils.isNotEmpty(hisPublish)) {
                long hisMinDate = hisPublish.stream().filter(o -> Objects.nonNull(o.getPublishTimestamp()))
                        .mapToLong(PublishContentDTO::getPublishTimestamp).min().orElse(0);
                int explorationInterval = (int) ((article.getPublishTimestamp() - (hisMinDate / 1000)) / 86400);
                item.setFirstExplorationIntervalAvg(explorationInterval);
            }
            result.add(item);
            saveList.add(buildDatastatScore(publishSortLog, item, article));
        }
        saveDatastatScore(dateStrList, saveList);
        result = result.stream().filter(o -> o.getIndex() == 1).collect(Collectors.toList());
        result.sort(Comparator.comparing(FirstContentScoreExport::getDateStr).reversed()
                .thenComparing(FirstContentScoreExport::getGhId));
        return result;
    }

    private DatastatScore buildDatastatScore(PublishSortLog publishSortLog, FirstContentScoreExport value, Article article) {
        DatastatScore item = new DatastatScore();
        item.setDt(value.getDateStr());
        item.setGhId(value.getGhId());
        item.setAccountName(value.getAccountName());
        item.setIndex(value.getIndex());
        item.setTitle(value.getTitle());
        item.setCategory(value.getCategory());
        item.setStrategy(value.getStrategy());
        item.setScore(value.getScore());
        item.setHisFissionAvgReadRateRate(value.getHisFissionAvgReadRateRateStrategy());
        item.setHisFissionAvgReadSumRate(value.getHisFissionAvgReadSumRateStrategy());
        item.setSimilarity(value.getSimilarityStrategy());
        item.setCategoryScore(value.getCategoryStrategy());
        item.setViewCountRate(value.getViewCountRateStrategy());
        item.setHisFissionDeWeightAvgReadSumRate(value.getHisFissionDeWeightAvgReadSumRateStrategy());
        item.setReadCount(value.getReadCount());
        item.setReadAvg(value.getReadAvg());
        item.setReadAvgRate(value.getReadAvgRate());
        item.setFirstPubInterval(value.getFirstExplorationIntervalAvg());
        item.setPublishContentId(publishSortLog.getPublishContentId());
        item.setCrawlerChannelContentId(publishSortLog.getCrawlerChannelContentId());
        item.setSourceId(publishSortLog.getSourceId());
        item.setPublishTimestamp(article.getPublishTimestamp());
        return item;
    }

    private void saveDatastatScore(List<String> dateStrList, List<DatastatScore> saveList) {
        if (CollectionUtils.isNotEmpty(saveList)) {
            longArticleBaseMapper.deleteDatastatScoreByDtIn(dateStrList);
            for (List<DatastatScore> saveListPartition : Lists.partition(saveList, 1000)) {
                longArticleBaseMapper.batchInsertDatastatScore(saveListPartition);
            }
        }
    }

    @XxlJob("producePlanAuditExport")
    public ReturnT<String> producePlanAuditExportJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 1);
        producePlanAuditExport(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void producePlanAuditExport(String dateStr) {
        if (!StringUtils.hasText(dateStr)) {
            dateStr = DateUtils.getBeforeDaysDateStr("yyyyMMdd", 1);
        }
        producePlanAuditExport(Collections.singletonList(dateStr));
    }

    public void producePlanAuditExport(List<String> dateStrList) {
        List<ProducePlanAuditExport> exportList = new ArrayList<>();
        dateStrList = Lists.reverse(dateStrList);
        for (String dateStr : dateStrList) {
            Map<String, ProducePlanAuditExport> yesterdayMap = getOldProducePlanAuditExport(dateStr, dailyDetailSheetToken, "28RgAZ");
            exportList.addAll(buildProducePlanAuditExport(dateStr, yesterdayMap));
        }
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = ProducePlanAuditExport.class.getDeclaredFields();
        for (ProducePlanAuditExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("I", "0%")
                );

        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "28RgAZ", rowNum, rows,
                2, styles, null, null);
    }

    private Map<String, ProducePlanAuditExport> getOldProducePlanAuditExport(String dateStr, String sheetToken, String sheetId) {
        String yesterday = DateUtils.getBeforeDaysDateStr(dateStr, "yyyyMMdd", 1);
        Pair<String, Integer> token = FeiShu.requestAccessToken();
        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.add("Authorization", "Bearer " + token.getFirst());
        HttpEntity<Object> queryEntity = new HttpEntity<>(httpHeaders);
        ResponseEntity<String> queryResponseEntity = restTemplate.exchange(
                String.format("https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/%s/values/%s!A"
                        + 2 + ":H" + 51, sheetToken, sheetId),
                HttpMethod.GET, queryEntity, String.class);
        JSONArray values = JSON.parseObject(queryResponseEntity.getBody())
                .getJSONObject("data")
                .getJSONObject("valueRange")
                .getJSONArray("values");
        Map<String, ProducePlanAuditExport> yesterdayMap = new HashMap<>();
        for (int i = 0; i < values.size(); i++) {
            JSONArray row = values.getJSONArray(i);
            if (!yesterday.equals(row.getString(0))) {
                continue;
            }
            ProducePlanAuditExport item = new ProducePlanAuditExport();
            item.setDateStr(row.getString(0));
            item.setPlanName(row.getString(1));
            item.setHisNotAuditCount(row.getInteger(2));
            item.setProduceCount(row.getInteger(3));
            item.setAuditCount(row.getInteger(5));
            item.setAuditPassCount(row.getInteger(6));
            item.setAuditFailCount(row.getInteger(7));
            yesterdayMap.put(item.getPlanName(), item);
        }
        return yesterdayMap;
    }

    private List<ProducePlanAuditExport> buildProducePlanAuditExport(String dateStr,
                                                                     Map<String, ProducePlanAuditExport> yesterdayMap) {
        Long timeStamp = DateUtils.getStartOfDay(dateStr, "yyyyMMdd") * 1000;
        List<String> planIds = auditProducePlanList;
        List<ProducePlan> producePlans = producePlanRepository.findByIdIn(auditProducePlanList);
        Map<String, String> producePlanMap = producePlans.stream().collect(Collectors.toMap(ProducePlan::getId, ProducePlan::getName));
        List<ProducePlanAuditCheckDTO> producePlanAudtiList = aigcBaseMapper.getProducePlanAudit(
                timeStamp, timeStamp + 86400000, planIds);
        Map<String, List<ProducePlanAuditCheckDTO>> producePlanAuditMap = producePlanAudtiList.stream()
                .collect(Collectors.groupingBy(ProducePlanAuditCheckDTO::getPlanId));
        List<ProducePlanAuditCheckDTO> producePlanProduceList = aigcBaseMapper.getProducePlanProduce(
                timeStamp, timeStamp + 86400000, planIds);
        Map<String, Integer> producePlanProduceMap = producePlanProduceList.stream()
                .collect(Collectors.toMap(ProducePlanAuditCheckDTO::getPlanId, ProducePlanAuditCheckDTO::getNum));
        List<ProducePlanAuditExport> exportList = new ArrayList<>();
        Integer totalAuditNum = 0, totalAuditPassNum = 0, totalWaitingAuditNum = 0, totalAuditFailNum = 0, totalProduceNum = 0;
        for (String planId : planIds) {
            List<ProducePlanAuditCheckDTO> auditCheckDTOList = producePlanAuditMap.get(planId);
            Integer yesterdayAuditNum = 0, yesterdayAuditPassNum = 0, waitingAuditNum = 0, yesterdayAuditFailNum = 0;
            if (CollectionUtils.isNotEmpty(auditCheckDTOList)) {
                for (ProducePlanAuditCheckDTO producePlanAuditCheckDTO : auditCheckDTOList) {
                    if (Objects.equals(producePlanAuditCheckDTO.getAuditStatus(), ProduceContentAuditStatusEnum.waiting.getVal())) {
                        waitingAuditNum += producePlanAuditCheckDTO.getNum();
                        totalWaitingAuditNum += producePlanAuditCheckDTO.getNum();
                    } else if (Objects.equals(producePlanAuditCheckDTO.getAuditStatus(), ProduceContentAuditStatusEnum.pass.getVal())) {
                        yesterdayAuditPassNum += producePlanAuditCheckDTO.getNum();
                        totalAuditPassNum += producePlanAuditCheckDTO.getNum();
                        yesterdayAuditNum += producePlanAuditCheckDTO.getNum();
                        totalAuditNum += producePlanAuditCheckDTO.getNum();
                    } else if (Objects.equals(producePlanAuditCheckDTO.getAuditStatus(), ProduceContentAuditStatusEnum.reject.getVal())) {
                        yesterdayAuditNum += producePlanAuditCheckDTO.getNum();
                        totalAuditNum += producePlanAuditCheckDTO.getNum();
                        yesterdayAuditFailNum += producePlanAuditCheckDTO.getNum();
                        totalAuditFailNum += producePlanAuditCheckDTO.getNum();
                    }
                }
            }
            String planName = producePlanMap.get(planId);
            ProducePlanAuditExport yesterdayExport = yesterdayMap.get(planName);
            Integer produceCount = producePlanProduceMap.getOrDefault(planId, 0);
            totalProduceNum += produceCount;
            ProducePlanAuditExport export = new ProducePlanAuditExport();
            export.setDateStr(dateStr);
            export.setPlanName(planName);
            export.setProduceCount(produceCount);
            if (Objects.nonNull(yesterdayExport)) {
                export.setRealProduceCount(waitingAuditNum + yesterdayAuditNum - yesterdayExport.getHisNotAuditCount());
            }
            export.setAuditCount(yesterdayAuditNum);
            export.setAuditPassCount(yesterdayAuditPassNum);
            export.setHisNotAuditCount(waitingAuditNum);
            export.setAuditFailCount(yesterdayAuditFailNum);
            if (yesterdayAuditNum > 0) {
                export.setAuditPassRate(yesterdayAuditPassNum * 1.0 / yesterdayAuditNum);
            }
            exportList.add(export);
        }
        ProducePlanAuditExport yesterdayExport = yesterdayMap.get("SUM");
        ProducePlanAuditExport sum = new ProducePlanAuditExport();
        sum.setDateStr(dateStr);
        sum.setPlanName("SUM");
        sum.setProduceCount(totalProduceNum);
        if (Objects.nonNull(yesterdayExport)) {
            sum.setRealProduceCount(totalWaitingAuditNum + totalAuditNum - yesterdayExport.getHisNotAuditCount());
        }
        sum.setAuditCount(totalAuditNum);
        sum.setAuditPassCount(totalAuditPassNum);
        sum.setHisNotAuditCount(totalWaitingAuditNum);
        sum.setAuditFailCount(totalAuditFailNum);
        if (totalAuditNum > 0) {
            sum.setAuditPassRate(totalAuditPassNum * 1.0 / totalAuditNum);
        }
        exportList.add(0, sum);
        return exportList;
    }


    @XxlJob("dailySafeScoreExport")
    public ReturnT<String> dailySafeScoreExportJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 3);
        dailySafeScore(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void dailySafeScore(String dateStr) {
        List<String> dateStrList = DateUtils.getBeforeDays(dateStr, null, 3);
        if (!StringUtils.hasText(dateStr)) {
            dateStrList = DateUtils.getBeforeDays(null, null, 3);
        }
        dailySafeScore(dateStrList);
    }

    public void dailySafeScore(List<String> dateStrList) {
        List<ProduceSafeScoreExport> exportList = getProduceSafeScoreExport(dateStrList.get(0));
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = ProduceSafeScoreExport.class.getDeclaredFields();
        for (ProduceSafeScoreExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        doSendFeishuSheet(dateStrList, dailySafeSheetToken, "9fc2e8", rowNum, rows,
                2, null, null, null);
    }

    private List<ProduceSafeScoreExport> getProduceSafeScoreExport(String dateStr) {
        List<ProduceSafeScoreExport> result = new ArrayList<>();
        Long startTimeStamp = DateUtils.getStartOfDay(dateStr, "yyyyMMdd") * 1000;
        Long endTimeStamp = DateUtils.getTodayStart();
        List<ProduceTaskAtom> list = aigcBaseMapper.getProduceScoreGreaterThan(startTimeStamp, endTimeStamp);
        Set<String> titles = new HashSet<>();
        for (ProduceTaskAtom produceTaskAtom : list) {
            if (titles.contains(produceTaskAtom.getInput())) {
                continue;
            }
            ProduceSafeScoreExport res = new ProduceSafeScoreExport();
            res.setProduceContentId(produceTaskAtom.getPlanExeId());
            res.setScore(produceTaskAtom.getOutput());
            res.setDateStr(DateUtils.getDateString(produceTaskAtom.getCreateTimestamp()));
            String title = JSONObject.parseObject(produceTaskAtom.getInput()).getJSONArray("refDataList")
                    .getJSONObject(0).getString("dataValue");
            res.setTitle(title);
            titles.add(title);
            result.add(res);
        }
        return result;
    }

    @XxlJob("videoAuditExport")
    public ReturnT<String> videoAuditExportJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 1);
        videoAuditExport(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void videoAuditExport(String dateStr) {
        if (!StringUtils.hasText(dateStr)) {
            dateStr = DateUtils.getBeforeDaysDateStr("yyyyMMdd", 1);
        }
        videoAuditExport(Collections.singletonList(dateStr));
    }

    public void videoAuditExport(List<String> dateStrList) {
        List<VideoAuditExport> exportList = new ArrayList<>();
        dateStrList = Lists.reverse(dateStrList);
        for (String dateStr : dateStrList) {
            exportList.addAll(buildVideoAuditExport(dateStr));
        }
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = VideoAuditExport.class.getDeclaredFields();
        for (VideoAuditExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("H", "0.00%"),
                        Pair.of("K", "0.00%")
                );

        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "vddANt", rowNum, rows,
                2, styles, null, null);
    }

    private List<VideoAuditExport> buildVideoAuditExport(String dateStr) {
        List<VideoAuditExport> result = new ArrayList<>();
        long timestamp = DateUtils.getStartOfDay(dateStr, "yyyyMMdd") * 1000;
        // 按内容池区分
        List<LongArticleTitleAudit> waitingAuditList = titleAuditRepository.getByStatus(ArticleVideoAuditStatusEnum.WAITING.getCode());
        List<String> waitingAuditContentIds = waitingAuditList.stream().map(LongArticleTitleAudit::getContentId).collect(Collectors.toList());
        List<ContentPoolTypeDTO> waitingAuditPoolTypeDTOS = aigcBaseMapper.getContentPoolType(waitingAuditContentIds);
        Map<String, List<ContentPoolTypeDTO>> waitingAuditPoolTypeMap = waitingAuditPoolTypeDTOS.stream()
                .collect(Collectors.groupingBy(ContentPoolTypeDTO::getPoolType));
        List<LongArticleTitleAudit> auditList = titleAuditRepository.getByAuditTimestampBetween(timestamp, timestamp + 86400000);
        List<LongArticleCrawlerVideo> crawlerVideoList = crawlerVideoRepository.getByAuditTimestampBetween(timestamp, timestamp + 86400000);
        Map<String, List<LongArticleCrawlerVideo>> crawlerVideoMap = crawlerVideoList.stream()
                .collect(Collectors.groupingBy(LongArticleCrawlerVideo::getContentId));
        List<String> contentIds = auditList.stream().map(LongArticleTitleAudit::getContentId).collect(Collectors.toList());
        List<ContentPoolTypeDTO> poolTypeDTOS = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(contentIds)) {
            poolTypeDTOS = aigcBaseMapper.getContentPoolType(contentIds);
        }
        Map<String, ContentPoolTypeDTO> poolTypeMap = poolTypeDTOS.stream().collect(Collectors.toMap(ContentPoolTypeDTO::getContentId, o -> o));
        Map<String, VideoAuditExport> map = new HashMap<>();
        ContentPoolEnum[] poolEnums = {ContentPoolEnum.autoArticlePoolLevel1, ContentPoolEnum.autoArticlePoolLevel3, ContentPoolEnum.autoArticlePoolLevel4};
        for (ContentPoolEnum contentPool : poolEnums) {
            VideoAuditExport videoAuditExport = new VideoAuditExport();
            videoAuditExport.setDateStr(dateStr);
            videoAuditExport.setPoolType(contentPool.getContentPool());
            map.put(contentPool.getContentPool(), videoAuditExport);
        }
        for (LongArticleTitleAudit titleAudit : auditList) {
            ContentPoolTypeDTO poolTypeDTO = poolTypeMap.get(titleAudit.getContentId());
            if (!map.containsKey(poolTypeDTO.getPoolType())) {
                VideoAuditExport videoAuditExport = new VideoAuditExport();
                videoAuditExport.setDateStr(dateStr);
                videoAuditExport.setPoolType(poolTypeDTO.getPoolType());
                map.put(poolTypeDTO.getPoolType(), videoAuditExport);
            }
            VideoAuditExport videoAuditExport = map.get(poolTypeDTO.getPoolType());
            videoAuditExport.setArticleAuditCount(videoAuditExport.getArticleAuditCount() + 1);
            if (titleAudit.getStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())) {
                videoAuditExport.setArticleAuditPassCount(videoAuditExport.getArticleAuditPassCount() + 1);
            }
            List<LongArticleCrawlerVideo> videoList = crawlerVideoMap.get(titleAudit.getContentId());
            if (CollectionUtils.isEmpty(videoList)) {
                continue;
            }
            videoAuditExport.setVideoAuditCount(videoAuditExport.getVideoAuditCount() + videoList.size());
            long videoAuditPassCount = videoList.stream()
                    .filter(o -> o.getStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())).count();
            videoAuditExport.setVideoAuditPassCount(videoAuditExport.getVideoAuditPassCount() + videoAuditPassCount);
        }
        for (Map.Entry<String, VideoAuditExport> entry : map.entrySet()) {
            VideoAuditExport videoAuditExport = entry.getValue();
            List<ContentPoolTypeDTO> watingAuditList = waitingAuditPoolTypeMap.get(videoAuditExport.getPoolType());
            ContentPoolEnum poolEnum = ContentPoolEnum.from(videoAuditExport.getPoolType());
            videoAuditExport.setPoolType(poolEnum.getDescription());
            if (videoAuditExport.getVideoAuditCount() > 0) {
                videoAuditExport.setArticleAuditPassRate(
                        videoAuditExport.getArticleAuditPassCount() * 1.0 / videoAuditExport.getArticleAuditCount());
            }
            if (CollectionUtils.isNotEmpty(watingAuditList)) {
                videoAuditExport.setWaitingAuditCount(watingAuditList.size());
            }
            result.add(videoAuditExport);
        }
        // sum
        long articleAuditCount = auditList.size();
        long articleAuditPassCount = auditList.stream()
                .filter(o -> o.getStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())).count();
        long videoAuditCount = crawlerVideoList.size();
        long videoAuditPassCount = crawlerVideoList.stream()
                .filter(o -> o.getStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())).count();
        VideoAuditExport sum = new VideoAuditExport();
        sum.setDateStr(dateStr);
        sum.setPoolType("SUM");
        sum.setWaitingAuditCount(waitingAuditList.size());
        sum.setArticleAuditCount(articleAuditCount);
        sum.setArticleAuditPassCount(articleAuditPassCount);
        sum.setVideoAuditCount(videoAuditCount);
        sum.setVideoAuditPassCount(videoAuditPassCount);
        if (sum.getVideoAuditCount() > 0) {
            sum.setArticleAuditPassRate(sum.getArticleAuditPassCount() * 1.0 / sum.getArticleAuditCount());
        }
        result.add(sum);
        result.sort(Comparator.comparing(VideoAuditExport::getPoolType));
        return result;
    }

    @XxlJob("contentFunnelExport")
    public ReturnT<String> contentFunnelExportJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 1);
        contentFunnelExport(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void contentFunnelExport(String dateStr) {
        if (!StringUtils.hasText(dateStr)) {
            dateStr = DateUtils.getBeforeDaysDateStr("yyyyMMdd", 1);
        }
        contentFunnelExport(Collections.singletonList(dateStr));
    }

    public void contentFunnelExport(List<String> dateStrList) {
        List<ContentFunnelExport> exportList = new ArrayList<>();
        dateStrList = Lists.reverse(dateStrList);
        for (String dateStr : dateStrList) {
            exportList.add(buildContentFunnelExport(dateStr));
        }
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = ContentFunnelExport.class.getDeclaredFields();
        for (ContentFunnelExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("G", "0.00%"),
                        Pair.of("J", "0.00%"),
                        Pair.of("M", "0.00%"),
                        Pair.of("N", "0.00%"),
                        Pair.of("R", "0.00%"),
                        Pair.of("U", "0.00%"),
                        Pair.of("V", "0.00%")
                );
        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "qEipyL", rowNum, rows,
                4, styles, null, null);
    }

    private ContentFunnelExport buildContentFunnelExport(String dateStr) {
        ContentFunnelExport result = new ContentFunnelExport();
        Long start = DateUtils.getStartOfDay(dateStr, "yyyyMMdd") * 1000;
        Long end = start + 86400000;
        List<String> producePlanIds = aigcBaseMapper.getProducePlanId();
        List<String> crawlerPlanIds = aigcBaseMapper.getCrawlerPlanByProducePlanIds(producePlanIds);
        Long crawlerCount = aigcBaseMapper.getCrawlerContentCountByCrawlerPlanIds(crawlerPlanIds, start, end);
        Long planCrawlerCount = 0L;
        List<String> crawlerSuccessPlanIds = aigcBaseMapper.getCrawlerSuccessPlanByCrawlerPlanIds(crawlerPlanIds, start, end);
        List<CrawlerPlan> crawlerPlanList = aigcBaseMapper.getCrawlerPlanByPlanIds(crawlerSuccessPlanIds);
        for (CrawlerPlan crawlerPlan : crawlerPlanList) {
            JSONObject crawlerModeValue = JSONObject.parseObject(crawlerPlan.getCrawlerModeValue());
            if (crawlerModeValue == null) {
                continue;
            }
            JSONObject sourceModeValues = crawlerModeValue.getJSONObject("sourceModeValues");
            if (sourceModeValues == null) {
                continue;
            }
            JSONArray inputModeValues = sourceModeValues.getJSONArray("inputModeValues");
            if (inputModeValues == null) {
                continue;
            }
            planCrawlerCount += inputModeValues.size();
        }
        Long produceCount = aigcBaseMapper.getProduceContentCountByProducePlanIds(producePlanIds, start, end);
        List<Integer> auditStatus = new ArrayList<>();
        auditStatus.add(1);
        Long produceAuditPassCount = aigcBaseMapper.getProduceAuditPassCountByProducePlanIds(producePlanIds, auditStatus, start, end);
        auditStatus.add(2);
        Long produceAuditCount = aigcBaseMapper.getProduceAuditPassCountByProducePlanIds(producePlanIds, auditStatus, start, end);
        Date dateStart = DateUtils.getStartDateOfDay(start / 1000);
        Date dateEnd = DateUtils.getStartDateOfDay(end / 1000);
        Long matchSuccessCount = longArticleBaseMapper.countMatchSuccessCount(dateStart, dateEnd);
        Long matchCount = longArticleBaseMapper.countMatchCount(dateStart, dateEnd);
        Long videoAuditPassCount = longArticleTitleAuditRepository.countByStatusAndAuditTimestampBetween(
                1, start, end);
        Long videoAuditCount = longArticleTitleAuditRepository.countByAuditTimestampBetween(start, end);
        List<PublishSingleVideoSource> videoPoolCrawlerCount = videoPoolRepository.getByCrawlerTimestampBetweenAndBadStatus(
                start / 1000, end / 1000, ArticleVideoBadStatusEnum.TITLE_DEFAULT_STATUS.getCode());
        List<PublishSingleVideoSource> videoPoolPQAuditCount = videoPoolRepository.getByAuditTimestampBetween(
                start / 1000, end / 1000);
        List<PublishSingleVideoSource> videoPoolAuditList = videoPoolRepository.getByVideoPoolAuditTimestampBetween(
                start, end);

        result.setDateStr(dateStr);
        result.setPlanCrawlerCount(planCrawlerCount);
        result.setCrawlerCount(crawlerCount);
        result.setProduceCount(produceCount);
        result.setProduceAuditPassCount(produceAuditPassCount);
        result.setProduceAuditCount(produceAuditCount);
        if (produceAuditCount > 0) {
            result.setProduceAuditPassRate(produceAuditPassCount * 1.0 / produceAuditCount);
        }
        result.setMatchSuccessCount(matchSuccessCount);
        result.setMatchCount(matchCount);
        if (matchCount > 0) {
            result.setMatchSuccessRate(matchSuccessCount * 1.0 / matchCount);
        }
        result.setVideoAuditPassCount(videoAuditPassCount);
        result.setVideoAuditCount(videoAuditCount);
        if (videoAuditCount > 0) {
            result.setVideoAuditPassRate(videoAuditPassCount * 1.0 / videoAuditCount);
        }
        result.setArticleAuditPassRate(result.getVideoAuditPassCount() * 1.0 / result.getProduceCount());
        result.setVideoPoolCrawlerCount((long) videoPoolCrawlerCount.size());
        result.setVideoPoolPQAuditCount((long) videoPoolPQAuditCount.size());
        long videoPoolPQAuditPassCount = videoPoolPQAuditCount.stream()
                .filter(o -> o.getAuditStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())).count();
        result.setVideoPoolPQAuditPassCount(videoPoolPQAuditPassCount);
        if (result.getVideoPoolPQAuditCount() > 0) {
            result.setVideoPoolPQAuditPassRate(videoPoolPQAuditPassCount * 1.0 / result.getVideoPoolPQAuditCount());
        }
        result.setVideoPoolAuditCount((long) videoPoolAuditList.size());
        long videoPoolAuditPassCount = videoPoolAuditList.stream()
                .filter(o -> o.getVideoPoolAuditStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())).count();
        result.setVideoPoolAuditPassCount(videoPoolAuditPassCount);
        if (result.getVideoPoolAuditCount() > 0) {
            result.setVideoPoolAuditPassRate(videoPoolAuditPassCount * 1.0 / result.getVideoPoolAuditCount());
        }
        if (result.getVideoPoolCrawlerCount() > 0) {
            result.setVideoPoolCrawlerAuditPassRate(videoPoolAuditPassCount * 1.0 / result.getVideoPoolCrawlerCount());
        }
        return result;
    }

    @XxlJob("contentGroupFunnelExport")
    public ReturnT<String> contentGroupFunnelExportJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 1);
        contentGroupFunnelExport(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void contentGroupFunnelExport(String dateStr) {
        if (!StringUtils.hasText(dateStr)) {
            dateStr = DateUtils.getBeforeDaysDateStr("yyyyMMdd", 1);
        }
        contentGroupFunnelExport(Collections.singletonList(dateStr));
    }

    public void contentGroupFunnelExport(List<String> dateStrList) {
        List<ContentGroupFunnelExport> exportList = new ArrayList<>();
        dateStrList = Lists.reverse(dateStrList);
        for (String dateStr : dateStrList) {
            exportList.addAll(buildContentGroupFunnelExport(dateStr));
        }
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = ContentGroupFunnelExport.class.getDeclaredFields();
        for (ContentGroupFunnelExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("F", "0.00%"),
                        Pair.of("I", "0.00%"),
                        Pair.of("L", "0.00%"),
                        Pair.of("O", "0.00%"),
                        Pair.of("R", "0.00%")
                );
        List<Pair<String, List<Pair<String, String>>>> thank = Arrays
                .asList(
                        Pair.of("B", Arrays.asList(
                                Pair.of("SUM", "#BACEFD"),
                                Pair.of("文章", "#FED4A4"),
                                Pair.of("视频", "#B1E8FC"))),
                        Pair.of("C", Arrays.asList(
                                Pair.of("SUM", "#BACEFD"),
                                Pair.of("公众号文章", "#FED4A4"),
                                Pair.of("头条文章", "#B1E8FC"),
                                Pair.of("公众号视频", "#F8E6AB"),
                                Pair.of("好看视频", "#A9EFE6"),
                                Pair.of("视频号视频", "#FDE2E2"),
                                Pair.of("头条视频", "#ECE2FE"),
                                Pair.of("搜狐视频", "#D9F5D6")))
                );
        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "6aW60b", rowNum, rows,
                3, styles, null, thank);
    }

    private List<ContentGroupFunnelExport> buildContentGroupFunnelExport(String dateStr) {
        List<ContentGroupFunnelExport> result = new ArrayList<>();
        Long start = DateUtils.getStartOfDay(dateStr, "yyyyMMdd") * 1000;
        Long end = start + 86400000;
        Date dateStart = DateUtils.getStartDateOfDay(start / 1000);
        Date dateEnd = DateUtils.getStartDateOfDay(end / 1000);
        List<String> producePlanIds = aigcBaseMapper.getProducePlanId();
        List<String> crawlerPlanIds = aigcBaseMapper.getCrawlerPlanByProducePlanIds(producePlanIds);
        // 匹配
        List<String> matchSuccessIdList = longArticleBaseMapper.getMatchSuccessContentId(dateStart, dateEnd);
        List<String> matchIdList = longArticleBaseMapper.getMatchContentId(dateStart, dateEnd);
        // 视频审核
        List<LongArticleTitleAudit> videoAuditPassList = longArticleTitleAuditRepository.getByStatusAndAuditTimestampBetween(
                1, start, end);
        List<LongArticleTitleAudit> videoAuditList = longArticleTitleAuditRepository.getByAuditTimestampBetween(start, end);
        List<String> videoAuditPassIdList = videoAuditPassList.stream().map(LongArticleTitleAudit::getContentId).collect(Collectors.toList());
        List<String> videoAuditIdList = videoAuditList.stream().map(LongArticleTitleAudit::getContentId).collect(Collectors.toList());
        // 文章
        List<ChannelEnum> channelList = Arrays.asList(ChannelEnum.wx, ChannelEnum.toutiao);
        for (ChannelEnum channel : channelList) {
            Long crawlerCount = aigcBaseMapper.getCrawlerContentCountByCrawlerPlanIdsAndChannel(crawlerPlanIds, start, end, channel.getVal());
            Long produceCount = aigcBaseMapper.getProduceContentCountByProducePlanIdsAndChannel(producePlanIds, start, end, channel.getVal());
            List<Integer> auditStatus = new ArrayList<>();
            auditStatus.add(1);
            Long produceAuditPassCount = aigcBaseMapper.getProduceAuditPassCountByProducePlanIdsAndChannel(producePlanIds, auditStatus, start, end, channel.getVal());
            auditStatus.add(2);
            Long produceAuditCount = aigcBaseMapper.getProduceAuditPassCountByProducePlanIdsAndChannel(producePlanIds, auditStatus, start, end, channel.getVal());
            List<IdChannelDTO> matchSuccessList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(matchSuccessIdList)) {
                matchSuccessList = aigcBaseMapper.getIdChannelByContentId(matchSuccessIdList);
            }
            List<IdChannelDTO> matchList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(matchIdList)) {
                matchList = aigcBaseMapper.getIdChannelByContentId(matchIdList);
            }
            List<IdChannelDTO> videoAuditPassIdChannelList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(videoAuditPassIdList)) {
                videoAuditPassIdChannelList = aigcBaseMapper.getIdChannelByContentId(videoAuditPassIdList);
            }
            List<IdChannelDTO> videoAuditIdChannelList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(videoAuditIdList)) {
                videoAuditIdChannelList = aigcBaseMapper.getIdChannelByContentId(videoAuditIdList);
            }
            ContentGroupFunnelExport item = ContentGroupFunnelExport.getDefault();
            item.setDateStr(dateStr);
            item.setType("文章");
            item.setSource(channel.getDescription() + "文章");
            item.setCrawlerCount(crawlerCount);
            item.setProduceCount(produceCount);
            if (item.getCrawlerCount() > 0) {
                item.setProduceRate(item.getProduceCount() * 1.0 / item.getCrawlerCount());
            }
            item.setProduceAuditCount(produceAuditCount);
            item.setProduceAuditPassCount(produceAuditPassCount);
            if (produceAuditCount > 0) {
                item.setProduceAuditPassRate(produceAuditPassCount * 1.0 / produceAuditCount);
            }
            item.setMatchCount(matchList.stream().filter(o -> o.getChannel().equals(channel.getVal())).count());
            item.setMatchSuccessCount(matchSuccessList.stream().filter(o -> o.getChannel().equals(channel.getVal())).count());
            if (item.getMatchCount() > 0) {
                item.setMatchSuccessRate(item.getMatchSuccessCount() * 1.0 / item.getMatchCount());
            }
            item.setVideoAuditCount(videoAuditIdChannelList.stream().filter(o -> o.getChannel().equals(channel.getVal())).count());
            item.setVideoAuditPassCount(videoAuditPassIdChannelList.stream().filter(o -> o.getChannel().equals(channel.getVal())).count());
            if (item.getVideoAuditCount() > 0) {
                item.setVideoAuditPassRate(item.getVideoAuditPassCount() * 1.0 / item.getVideoAuditCount());
            }
            result.add(item);
        }
        // 视频
        List<VideoPoolPlatformEnum> videoPoolType = Arrays.asList(VideoPoolPlatformEnum.GZH, VideoPoolPlatformEnum.HkSP,
                VideoPoolPlatformEnum.SPH, VideoPoolPlatformEnum.TOUTIAO, VideoPoolPlatformEnum.SOHU);
        for (VideoPoolPlatformEnum videoType : videoPoolType) {
            ContentGroupFunnelExport item = ContentGroupFunnelExport.getDefault();
            item.setDateStr(dateStr);
            item.setType("视频");
            item.setSource(videoType.getDescription());
            long videoPoolCrawlerCount = aigcBaseMapper.getVideoPoolPlatformCrawlerCount(start, end, videoType.getPlatform());
            item.setCrawlerCount(videoPoolCrawlerCount);
            Long produceCount = aigcBaseMapper.getVideoPoolPlatformProduceCount(producePlanIds, start, end, videoType.getPlatform());
            item.setProduceCount(produceCount);
            if (item.getCrawlerCount() > 0) {
                item.setProduceRate(item.getProduceCount() * 1.0 / item.getCrawlerCount());
            }
            List<Integer> auditStatus = new ArrayList<>();
            auditStatus.add(1);
            Long produceAuditPassCount = aigcBaseMapper.getVideoPoolPlatformProduceAuditPassCount(producePlanIds, auditStatus, start, end, videoType.getPlatform());
            auditStatus.add(2);
            Long produceAuditCount = aigcBaseMapper.getVideoPoolPlatformProduceAuditPassCount(producePlanIds, auditStatus, start, end, videoType.getPlatform());
            item.setProduceAuditCount(produceAuditCount);
            item.setProduceAuditPassCount(produceAuditPassCount);
            if (produceAuditCount > 0) {
                item.setProduceAuditPassRate(produceAuditPassCount * 1.0 / produceAuditCount);
            }
            List<IdPlatformDTO> matchSuccessList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(matchSuccessIdList)) {
                matchSuccessList = aigcBaseMapper.getIdPlatformByContentId(matchSuccessIdList);
            }
            List<IdPlatformDTO> matchList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(matchIdList)) {
                matchList = aigcBaseMapper.getIdPlatformByContentId(matchIdList);
            }
            item.setMatchCount(matchList.stream().filter(o -> o.getPlatform().equals(videoType.getPlatform())).count());
            item.setMatchSuccessCount(matchSuccessList.stream().filter(o -> o.getPlatform().equals(videoType.getPlatform())).count());
            if (item.getMatchCount() > 0) {
                item.setMatchSuccessRate(item.getMatchSuccessCount() * 1.0 / item.getMatchCount());
            }
            List<PublishSingleVideoSource> videoPoolPQAuditCount = videoPoolRepository.getByAuditTimestampBetweenAndPlatform(
                    start / 1000, end / 1000, videoType.getPlatform());
            item.setVideoPoolPQAuditCount((long) videoPoolPQAuditCount.size());
            long videoPoolPQAuditPassCount = videoPoolPQAuditCount.stream()
                    .filter(o -> o.getAuditStatus().equals(ProduceContentAuditStatusEnum.pass.getVal())).count();
            item.setVideoPoolPQAuditPassCount(videoPoolPQAuditPassCount);
            if (item.getVideoPoolPQAuditCount() > 0) {
                item.setVideoPoolPQAuditPassRate(videoPoolPQAuditPassCount * 1.0 / item.getVideoPoolPQAuditCount());
            }
            List<IdPlatformDTO> videoAuditPassIdPlatformList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(videoAuditPassIdList)) {
                videoAuditPassIdPlatformList = aigcBaseMapper.getIdPlatformByContentId(videoAuditPassIdList);
            }
            List<IdPlatformDTO> videoAuditIdPlatformList = new ArrayList<>();
            if (CollectionUtils.isNotEmpty(videoAuditIdList)) {
                videoAuditIdPlatformList = aigcBaseMapper.getIdPlatformByContentId(videoAuditIdList);
            }
            item.setVideoAuditCount(videoAuditIdPlatformList.stream().filter(o -> o.getPlatform().equals(videoType.getPlatform())).count());
            item.setVideoAuditPassCount(videoAuditPassIdPlatformList.stream().filter(o -> o.getPlatform().equals(videoType.getPlatform())).count());
            if (item.getVideoAuditCount() > 0) {
                item.setVideoAuditPassRate(item.getVideoAuditPassCount() * 1.0 / item.getVideoAuditCount());
            }
            result.add(item);
        }
        // sum
        result.add(buildContentFunnelGroupSum(dateStr, result));
        return result;
    }

    private ContentGroupFunnelExport buildContentFunnelGroupSum(String dateStr, List<ContentGroupFunnelExport> result) {
        ContentGroupFunnelExport sum = ContentGroupFunnelExport.getDefault();
        sum.setType("SUM");
        sum.setSource("SUM");
        sum.setDateStr(dateStr);
        for (ContentGroupFunnelExport contentGroupFunnelExport : result) {
            sum.setCrawlerCount(sum.getCrawlerCount() + contentGroupFunnelExport.getCrawlerCount());
            sum.setProduceCount(sum.getProduceCount() + contentGroupFunnelExport.getProduceCount());
            if (sum.getCrawlerCount() > 0) {
                sum.setProduceRate(sum.getProduceCount() * 1.0 / sum.getCrawlerCount());
            }
            sum.setProduceAuditCount(sum.getProduceAuditCount() + contentGroupFunnelExport.getProduceAuditCount());
            sum.setProduceAuditPassCount(sum.getProduceAuditPassCount() + contentGroupFunnelExport.getProduceAuditPassCount());
            if (sum.getProduceAuditCount() > 0) {
                sum.setProduceAuditPassRate(sum.getProduceAuditPassCount() * 1.0 / sum.getProduceAuditCount());
            }
            sum.setMatchCount(sum.getMatchCount() + contentGroupFunnelExport.getMatchCount());
            sum.setMatchSuccessCount(sum.getMatchSuccessCount() + contentGroupFunnelExport.getMatchSuccessCount());
            if (sum.getMatchCount() > 0) {
                sum.setMatchSuccessRate(sum.getMatchSuccessCount() * 1.0 / sum.getMatchCount());
            }
            sum.setVideoAuditCount(sum.getVideoAuditCount() + contentGroupFunnelExport.getVideoAuditCount());
            sum.setVideoAuditPassCount(sum.getVideoAuditPassCount() + contentGroupFunnelExport.getVideoAuditPassCount());
            if (sum.getVideoAuditCount() > 0) {
                sum.setVideoAuditPassRate(sum.getVideoAuditPassCount() * 1.0 / sum.getVideoAuditCount());
            }
            sum.setVideoPoolPQAuditCount(sum.getVideoPoolPQAuditCount() + contentGroupFunnelExport.getVideoPoolPQAuditCount());
            sum.setVideoPoolPQAuditPassCount(sum.getVideoPoolPQAuditPassCount() + contentGroupFunnelExport.getVideoPoolPQAuditPassCount());
            if (sum.getVideoPoolPQAuditCount() > 0) {
                sum.setVideoPoolPQAuditPassRate(sum.getVideoPoolPQAuditPassCount() * 1.0 / sum.getVideoPoolPQAuditCount());
            }
        }
        return sum;
    }


    @XxlJob("contentEffectGroupBySourceExport")
    public ReturnT<String> contentEffectGroupBySourceJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 1);
        contentEffectGroupBySource(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void contentEffectGroupBySource(String dateStr) {
        if (!StringUtils.hasText(dateStr)) {
            dateStr = DateUtils.getBeforeDaysDateStr("yyyyMMdd", 1);
        }
        contentEffectGroupBySource(Collections.singletonList(dateStr));
    }

    public void contentEffectGroupBySource(List<String> dateStrList) {
        List<ContentEffectGroupBySourceExport> exportList = new ArrayList<>();
        dateStrList = Lists.reverse(dateStrList);
        for (String dateStr : dateStrList) {
            exportList.addAll(buildContentEffectGroupBySourceExport(dateStr));
        }
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = ContentEffectGroupBySourceExport.class.getDeclaredFields();
        for (ContentEffectGroupBySourceExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("H", "0.00%"),
                        Pair.of("L", "0.00%"),
                        Pair.of("M", "0.00%"),
                        Pair.of("N", "0.00%"),
                        Pair.of("R", "0.00%"),
                        Pair.of("S", "0.00%"),
                        Pair.of("T", "0.00%")
                );
        List<Pair<String, List<Pair<String, String>>>> thank = Arrays
                .asList(
                        Pair.of("B", Arrays.asList(
                                Pair.of("SUM", "#BACEFD"),
                                Pair.of("文章", "#FED4A4"),
                                Pair.of("视频", "#B1E8FC"),
                                Pair.of("文章SUM", "#F8E6AB"),
                                Pair.of("视频SUM", "#A9EFE6"))),
                        Pair.of("C", Arrays.asList(
                                Pair.of("SUM", "#BACEFD"),
                                Pair.of("公众号文章", "#FED4A4"),
                                Pair.of("头条文章", "#B1E8FC"),
                                Pair.of("公众号视频", "#F8E6AB"),
                                Pair.of("好看视频", "#A9EFE6"),
                                Pair.of("视频号视频", "#FDE2E2"),
                                Pair.of("头条视频", "#ECE2FE"),
                                Pair.of("文章SUM", "#D9F5D6"),
                                Pair.of("视频SUM", "#F8DEF8"),
                                Pair.of("搜狐视频", "#EEF6C6"))),
                        Pair.of("D", Arrays.asList(
                                Pair.of("SUM", "#BACEFD"),
                                Pair.of("相同", "#FED4A4"),
                                Pair.of("不同", "#B1E8FC")))
                );
        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "qvxJsD", rowNum, rows,
                2, styles, null, thank);
    }

    private List<ContentEffectGroupBySourceExport> buildContentEffectGroupBySourceExport(String dateStr) {
        List<ContentEffectGroupBySourceExport> result = buildContentEffectGroupBySource(dateStr);
        Long start = DateUtils.getStartOfDay(dateStr, "yyyyMMdd");
        Long end = start + 86400;
        List<Article> articleList = articleRepository.getByPublishTimestampBetweenAndTypeEquals(start, end, ArticleTypeEnum.QUNFA.getVal());
        List<String> wxSnList = articleList.stream().map(Article::getWxSn).collect(Collectors.toList());
        List<ArticleDetailInfo> articleDetailInfoList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(wxSnList, 1000)) {
            articleDetailInfoList.addAll(articleDetailInfoRepository.getByWxSnIn(partitions));
        }
        List<DatastatSortStrategy> datastatSortStrategyList = datastatSortStrategyRepository.getByWxSnIn(wxSnList);
        Map<String, DatastatSortStrategy> datastatSortStrategyMap = datastatSortStrategyList.stream()
                .collect(Collectors.toMap(DatastatSortStrategy::getWxSn, Function.identity()));
        Map<String, List<ArticleDetailInfo>> articleDetailInfoMap = articleDetailInfoList.stream()
                .collect(Collectors.groupingBy(ArticleDetailInfo::getWxSn));
        // 获取rootSourceId
        Map<String, List<String>> rootSourceIdMap = new HashMap<>();
        List<String> rootSourceIdList = new ArrayList<>();
        for (Article article : articleList) {
            List<String> rootSourceIds = JSONArray.parseArray(article.getRootSourceIdList(), String.class);
            rootSourceIdMap.put(article.getWxSn(), rootSourceIds);
            rootSourceIdList.addAll(rootSourceIds);
        }
        List<LongArticlesRootSourceId> longArticlesRootSourceIdList = rootSourceIdRepository.getByRootSourceIdIn(rootSourceIdList);
        Map<String, LongArticlesRootSourceId> longArticlesRootSourceIdMap = longArticlesRootSourceIdList.stream()
                .collect(Collectors.toMap(LongArticlesRootSourceId::getRootSourceId, Function.identity()));
        // 获取视频
        List<String> contentIdList = longArticlesRootSourceIdList.stream().map(LongArticlesRootSourceId::getContentId).distinct().collect(Collectors.toList());
        List<LongArticleCrawlerVideo> longArticleCrawlerVideoList = crawlerVideoRepository.getByContentIdInAndIsIllegal(contentIdList, 0);
        Map<String, List<LongArticleCrawlerVideo>> longArticleCrawlerVideoMap = longArticleCrawlerVideoList.stream()
                .collect(Collectors.groupingBy(LongArticleCrawlerVideo::getContentId));
        for (Article article : articleList) {
            boolean isVideo = false;
            boolean isSameMiniProgram = false;
            String source = "";
            List<String> rootSourceIds = rootSourceIdMap.get(article.getWxSn());
            if (CollectionUtil.isNotEmpty(rootSourceIds)) {
                List<LongArticlesRootSourceId> rootSourceIdItemList = new ArrayList<>();
                for (String rootSourceId : rootSourceIds) {
                    LongArticlesRootSourceId longArticlesRootSourceId = longArticlesRootSourceIdMap.get(rootSourceId);
                    if (Objects.isNull(longArticlesRootSourceId)) {
                        continue;
                    }
                    rootSourceIdItemList.add(longArticlesRootSourceId);
                }
                String contentId = rootSourceIdItemList.get(0).getContentId();
                List<LongArticleCrawlerVideo> crawlerVideoList = longArticleCrawlerVideoMap.get(contentId);
                List<String> videoOssPaths = crawlerVideoList.stream().map(LongArticleCrawlerVideo::getVideoOssPath)
                        .filter(StringUtils::hasText).collect(Collectors.toList());
                List<PublishSingleVideoSource> singleVideoSources = videoPoolRepository.getByVideoOssPathIn(videoOssPaths);
                if (CollectionUtil.isNotEmpty(singleVideoSources)) {
                    isVideo = true;
                    source = VideoPoolPlatformEnum.from(singleVideoSources.get(0).getPlatform()).getDescription();
                }
                if (CollectionUtil.isNotEmpty(crawlerVideoList) && crawlerVideoList.size() == 1) {
                    isSameMiniProgram = true;
                }
            }
            List<ArticleDetailInfo> detailInfoList = articleDetailInfoMap.get(article.getWxSn());
            DatastatSortStrategy datastatSortStrategy = datastatSortStrategyMap.get(article.getWxSn());
            if (isVideo) {
                addContentEffectGroupBySourceRate(article, "视频", source, isSameMiniProgram, result, detailInfoList,
                        datastatSortStrategy);
            } else {
                addContentEffectGroupBySourceRate(article, "文章", source, isSameMiniProgram, result, detailInfoList,
                        datastatSortStrategy);
            }
        }
        for (ContentEffectGroupBySourceExport export : result) {
            setContentEffectGroupBySourceRate(export);
        }

        result.add(buildContentEffectGroupBySourceSum(dateStr, result));
        return result;
    }

    private void addContentEffectGroupBySourceRate(Article article, String type, String source,
                                                   boolean isSameMiniProgram,
                                                   List<ContentEffectGroupBySourceExport> result,
                                                   List<ArticleDetailInfo> detailInfoList,
                                                   DatastatSortStrategy datastatSortStrategy) {
        if (Objects.isNull(datastatSortStrategy)) {
            return;
        }
        if ("文章".equals(type) && "".equals(source)) {
            source = getArticleSource(datastatSortStrategy);
        }
        for (ContentEffectGroupBySourceExport export : result) {
            if ((export.getType().contains("SUM") && export.getType().contains(type)) || export.getType().equals(type)) {
                if ((export.getIsSameMiniprogram().equals("相同") && isSameMiniProgram)
                        || (export.getIsSameMiniprogram().equals("不同") && !isSameMiniProgram)
                        || export.getIsSameMiniprogram().equals("SUM")) {
                    if (export.getSource().contains("SUM") || export.getSource().equals(source)) {
                        if (Objects.nonNull(datastatSortStrategy.getFans())) {
                            export.setFansCount(export.getFansCount() + datastatSortStrategy.getFans());
                        }
                        export.setPublishContentCount(export.getPublishContentCount() + 1);
                        export.setReadCount(export.getReadCount() + article.getShowViewCount());
                        if (CollectionUtil.isNotEmpty(detailInfoList)) {
                            int totalFirstLevel = 0;
                            int totalT0Fission = 0;
                            int card1FirstLevel = 0;
                            int card1T0Fission = 0;
                            int card2FirstLevel = 0;
                            int card2T0Fission = 0;
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                if (Objects.isNull(articleDetailInfo.getFirstLevel())) {
                                    continue;
                                }
                                if (articleDetailInfo.getVideoIndex() == 1) {
                                    card1FirstLevel += articleDetailInfo.getFirstLevel();
                                    if (Objects.nonNull(articleDetailInfo.getFission0())) {
                                        card1T0Fission += articleDetailInfo.getFission0();
                                    }
                                } else if (articleDetailInfo.getVideoIndex() == 2) {
                                    card2FirstLevel += articleDetailInfo.getFirstLevel();
                                    if (Objects.nonNull(articleDetailInfo.getFission0())) {
                                        card2T0Fission += articleDetailInfo.getFission0();
                                    }
                                }
                                totalFirstLevel += articleDetailInfo.getFirstLevel();
                                if (Objects.nonNull(articleDetailInfo.getFission0())) {
                                    totalT0Fission += articleDetailInfo.getFission0();
                                }
                            }
                            export.setFirstLevel(export.getFirstLevel() + totalFirstLevel);
                            export.setMiniprogram1FirstLevel(export.getMiniprogram1FirstLevel() + card1FirstLevel);
                            export.setMiniprogram2FirstLevel(export.getMiniprogram2FirstLevel() + card2FirstLevel);
                            export.setT0Fission(export.getT0Fission() + totalT0Fission);
                            export.setMiniprogram1T0Fission(export.getMiniprogram1T0Fission() + card1T0Fission);
                            export.setMiniprogram2T0Fission(export.getMiniprogram2T0Fission() + card2T0Fission);
                        }
                    }
                }
            }
        }
    }

    private String getArticleSource(DatastatSortStrategy datastatSortStrategy) {
        if (StringUtils.hasText(datastatSortStrategy.getProducePlanName())
                && datastatSortStrategy.getProducePlanName().contains("头条")) {
            return "头条文章";
        } else {
            return "公众号文章";
        }
    }


    private List<ContentEffectGroupBySourceExport> buildContentEffectGroupBySource(String dateStr) {
        List<ContentEffectGroupBySourceExport> result = new ArrayList<>();
        List<String> isSameMiniprogram = Arrays.asList("相同", "不同", "SUM");
        List<String> articleSource = Arrays.asList("公众号文章", "头条文章");
        List<String> videoSource = Arrays.asList("公众号视频", "好看视频", "视频号视频", "头条视频", "搜狐视频");
        for (String source : articleSource) {
            for (String same : isSameMiniprogram) {
                ContentEffectGroupBySourceExport item = new ContentEffectGroupBySourceExport();
                item.setDateStr(dateStr);
                item.setType("文章");
                item.setSource(source);
                item.setIsSameMiniprogram(same);
                result.add(item);
            }
        }
        for (String same : isSameMiniprogram) {
            ContentEffectGroupBySourceExport item = new ContentEffectGroupBySourceExport();
            item.setDateStr(dateStr);
            item.setType("文章SUM");
            item.setSource("文章SUM");
            item.setIsSameMiniprogram(same);
            result.add(item);
        }
        for (String source : videoSource) {
            ContentEffectGroupBySourceExport item = new ContentEffectGroupBySourceExport();
            item.setDateStr(dateStr);
            item.setType("视频");
            item.setSource(source);
            item.setIsSameMiniprogram("SUM");
            result.add(item);
        }
        ContentEffectGroupBySourceExport item = new ContentEffectGroupBySourceExport();
        item.setDateStr(dateStr);
        item.setType("视频SUM");
        item.setSource("视频SUM");
        item.setIsSameMiniprogram("SUM");
        result.add(item);
        return result;
    }

    private ContentEffectGroupBySourceExport buildContentEffectGroupBySourceSum(String dateStr, List<ContentEffectGroupBySourceExport> resultList) {
        ContentEffectGroupBySourceExport sum = new ContentEffectGroupBySourceExport();
        sum.setDateStr(dateStr);
        sum.setType("SUM");
        sum.setSource("SUM");
        sum.setIsSameMiniprogram("SUM");
        for (ContentEffectGroupBySourceExport export : resultList) {
            if (export.getType().contains("SUM")
                    || (export.getType().equals("文章") && export.getIsSameMiniprogram().equals("SUM"))) {
                continue;
            }
            sum.setFansCount(sum.getFansCount() + export.getFansCount());
            sum.setPublishContentCount(sum.getPublishContentCount() + export.getPublishContentCount());
            sum.setReadCount(sum.getReadCount() + export.getReadCount());
            sum.setFirstLevel(sum.getFirstLevel() + export.getFirstLevel());
            sum.setMiniprogram1FirstLevel(sum.getMiniprogram1FirstLevel() + export.getMiniprogram1FirstLevel());
            sum.setMiniprogram2FirstLevel(sum.getMiniprogram2FirstLevel() + export.getMiniprogram2FirstLevel());
            sum.setT0Fission(sum.getT0Fission() + export.getT0Fission());
            sum.setMiniprogram1T0Fission(sum.getMiniprogram1T0Fission() + export.getMiniprogram1T0Fission());
            sum.setMiniprogram2T0Fission(sum.getMiniprogram2T0Fission() + export.getMiniprogram2T0Fission());
            setContentEffectGroupBySourceRate(sum);
        }
        return sum;
    }

    private void setContentEffectGroupBySourceRate(ContentEffectGroupBySourceExport export) {
        if (Objects.nonNull(export.getFansCount()) && export.getFansCount() > 0) {
            export.setReadRate(export.getReadCount() * 1.0 / export.getFansCount());
        }
        if (Objects.nonNull(export.getReadCount()) && export.getReadCount() > 0) {
            export.setOpenRate(export.getFirstLevel() * 1.0 / export.getReadCount());
            export.setMiniprogram1OpenRate(export.getMiniprogram1FirstLevel() * 1.0 / export.getReadCount());
            export.setMiniprogram2OpenRate(export.getMiniprogram2FirstLevel() * 1.0 / export.getReadCount());
        }
        if (Objects.nonNull(export.getFirstLevel()) && export.getFirstLevel() > 0) {
            export.setT0FissionRate(export.getT0Fission() * 1.0 / export.getFirstLevel());
        }
        if (Objects.nonNull(export.getMiniprogram1FirstLevel()) && export.getMiniprogram1FirstLevel() > 0) {
            export.setMiniprogram1T0FissionRate(export.getMiniprogram1T0Fission() * 1.0 / export.getMiniprogram1FirstLevel());
        }
        if (Objects.nonNull(export.getMiniprogram2FirstLevel()) && export.getMiniprogram2FirstLevel() > 0) {
            export.setMiniprogram2T0FissionRate(export.getMiniprogram2T0Fission() * 1.0 / export.getMiniprogram2FirstLevel());
        }
    }

    @XxlJob("buildCoverStatisticDataExportJob")
    public ReturnT<String> buildCoverStatisticDataExportJob(String param) {
        if (StringUtils.hasText(param)) {
            coverStatisticDataExport(param);
            coverStatisticTestDataExport(param);
        } else {
            String dateStr = DateUtils.getDateString(System.currentTimeMillis() - 24 * 60 * 60 * 1000, "yyyMMdd");
            coverStatisticDataExport(dateStr);
            coverStatisticTestDataExport(dateStr);
        }
        return ReturnT.SUCCESS;
    }

    public void coverStatisticDataExport(String dateStr) {
        List<String> dateStrList = Arrays.asList(dateStr);
        List<CoverStatisticDataExport> exportList = buildCoverStatisticDataExport(dateStr);
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = CoverStatisticDataExport.class.getDeclaredFields();
        for (CoverStatisticDataExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }
        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "jwayC4", rowNum, rows,
                2, null, null, null);
    }

    public void coverStatisticTestDataExport(String dateStr) {
        List<String> dateStrList = Arrays.asList(dateStr);
        List<CoverStatisticOneDataExport> exportList = buildCoverStatisticTestDataExport(dateStr);
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = CoverStatisticOneDataExport.class.getDeclaredFields();
        for (CoverStatisticOneDataExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }
        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "QiEZiz", rowNum, rows,
                2, null, null, null);
    }


    private List<CoverStatisticDataExport> buildCoverStatisticDataExport(String dateStr) {
        List<CoverStatisticDataExport> result = new ArrayList<>();
        CoverStatisticDataExport articleTestFirst = new CoverStatisticDataExport(dateStr, "文章", "实验组", "头条");
        CoverStatisticDataExport articleTestSecond = new CoverStatisticDataExport(dateStr, "文章", "实验组", "次条");
        CoverStatisticDataExport articleTestLast = new CoverStatisticDataExport(dateStr, "文章", "实验组", "3-8条");
        CoverStatisticDataExport articleTestSum = new CoverStatisticDataExport(dateStr, "文章", "实验组", "sum");

        CoverStatisticDataExport articleBaseFirst = new CoverStatisticDataExport(dateStr, "文章", "base组", "头条");
        CoverStatisticDataExport articleBaseSecond = new CoverStatisticDataExport(dateStr, "文章", "base组", "次条");
        CoverStatisticDataExport articleBaseLast = new CoverStatisticDataExport(dateStr, "文章", "base组", "3-8条");
        CoverStatisticDataExport articleBaseSum = new CoverStatisticDataExport(dateStr, "文章", "base组", "sum");


        CoverStatisticDataExport articleMinimumFirst = new CoverStatisticDataExport(dateStr, "文章", "兜底组", "头条");
        CoverStatisticDataExport articleMinimumSecond = new CoverStatisticDataExport(dateStr, "文章", "兜底组", "次条");
        CoverStatisticDataExport articleMinimumLast = new CoverStatisticDataExport(dateStr, "文章", "兜底组", "3-8条");
        CoverStatisticDataExport articleMinimumSum = new CoverStatisticDataExport(dateStr, "文章", "兜底组", "sum");

        CoverStatisticDataExport articleSum = new CoverStatisticDataExport(dateStr, "文章", "sum", "sum");

        CoverStatisticDataExport videoTestFirst = new CoverStatisticDataExport(dateStr, "视频", "实验组", "头条");
        CoverStatisticDataExport videoTestSecond = new CoverStatisticDataExport(dateStr, "视频", "实验组", "次条");
        CoverStatisticDataExport videoTestLast = new CoverStatisticDataExport(dateStr, "视频", "实验组", "3-8条");
        CoverStatisticDataExport videoTestSum = new CoverStatisticDataExport(dateStr, "视频", "实验组", "sum");


        CoverStatisticDataExport videoBaseFirst = new CoverStatisticDataExport(dateStr, "视频", "base组", "头条");
        CoverStatisticDataExport videoBaseSecond = new CoverStatisticDataExport(dateStr, "视频", "base组", "次条");
        CoverStatisticDataExport videoBaseLast = new CoverStatisticDataExport(dateStr, "视频", "base组", "3-8条");
        CoverStatisticDataExport videoBaseSum = new CoverStatisticDataExport(dateStr, "视频", "base组", "sum");


        CoverStatisticDataExport videoMinimumFirst = new CoverStatisticDataExport(dateStr, "视频", "兜底组", "头条");
        CoverStatisticDataExport videoMinimumSecond = new CoverStatisticDataExport(dateStr, "视频", "兜底组", "次条");
        CoverStatisticDataExport videoMinimumLast = new CoverStatisticDataExport(dateStr, "视频", "兜底组", "3-8条");
        CoverStatisticDataExport videoMinimumSum = new CoverStatisticDataExport(dateStr, "视频", "兜底组", "sum");

        CoverStatisticDataExport videoSum = new CoverStatisticDataExport(dateStr, "视频", "sum", "sum");

        Long start = DateUtils.getStartOfDay(dateStr, "yyyyMMdd");
        Long end = start + 86400;
        Date startDate = new Date(start * 1000);
        Date endDate = new Date(end * 1000);
        List<Article> articleList = articleRepository.getByPublishTimestampBetweenAndTypeEquals(start, end, ArticleTypeEnum.QUNFA.getVal());
        List<String> wxSnList = articleList.stream().map(Article::getWxSn).collect(Collectors.toList());
        List<ArticleDetailInfo> articleDetailInfoList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(wxSnList, 1000)) {
            articleDetailInfoList.addAll(articleDetailInfoRepository.findByWxSnInAndPublishDtBetween(partitions, startDate, endDate));
        }
        List<DatastatSortStrategy> datastatSortStrategyList = datastatSortStrategyRepository.getByWxSnIn(wxSnList);
        Map<String, DatastatSortStrategy> datastatSortStrategyMap = datastatSortStrategyList.stream()
                .collect(Collectors.toMap(DatastatSortStrategy::getWxSn, Function.identity()));
        Map<String, List<ArticleDetailInfo>> articleDetailInfoMap = articleDetailInfoList.stream()
                .collect(Collectors.groupingBy(ArticleDetailInfo::getWxSn));
        // 获取rootSourceId
        Map<String, List<String>> rootSourceIdMap = new HashMap<>();
        List<String> rootSourceIdList = new ArrayList<>();
        for (Article article : articleList) {
            List<String> rootSourceIds = JSONArray.parseArray(article.getRootSourceIdList(), String.class);
            if (CollectionUtils.isEmpty(rootSourceIds)) {
                continue;
            }
            rootSourceIdMap.put(article.getWxSn(), rootSourceIds);
            rootSourceIdList.addAll(rootSourceIds);
        }
        List<LongArticlesRootSourceId> longArticlesRootSourceIdList = rootSourceIdRepository.getByRootSourceIdIn(rootSourceIdList);
        Map<String, LongArticlesRootSourceId> longArticlesRootSourceIdMap = longArticlesRootSourceIdList.stream()
                .collect(Collectors.toMap(LongArticlesRootSourceId::getRootSourceId, Function.identity()));
        // 获取视频
        List<String> contentIdList = longArticlesRootSourceIdList.stream().map(LongArticlesRootSourceId::getContentId).distinct().collect(Collectors.toList());
        List<LongArticleCrawlerVideo> longArticleCrawlerVideoList = crawlerVideoRepository.getByContentIdInAndIsIllegal(contentIdList, 0);
        Map<String, List<LongArticleCrawlerVideo>> longArticleCrawlerVideoMap = longArticleCrawlerVideoList.stream()
                .collect(Collectors.groupingBy(LongArticleCrawlerVideo::getContentId));
        for (Article article : articleList) {
            boolean isVideo = false;
            boolean isSameMiniProgram = false;
            boolean isTest = false;
            List<String> rootSourceIds = rootSourceIdMap.get(article.getWxSn());
            if (CollectionUtil.isNotEmpty(rootSourceIds)) {
                List<LongArticlesRootSourceId> rootSourceIdItemList = new ArrayList<>();
                for (String rootSourceId : rootSourceIds) {
                    LongArticlesRootSourceId longArticlesRootSourceId = longArticlesRootSourceIdMap.get(rootSourceId);
                    if (!Objects.isNull(longArticlesRootSourceId)) {
                        rootSourceIdItemList.add(longArticlesRootSourceId);
                    }
                    LongArticlesPublishMiniprogram longArticlesPublishMiniprogram
                            = longArticlesPublishMiniprogramRepository.findByRootSourceIdEquals(rootSourceId);
                    if (!Objects.isNull(longArticlesPublishMiniprogram)) {
                        if (longArticlesPublishMiniprogram.getNewVideoCoverId() != null) {
                            isTest = true;
                        }
                    }

                }
                String contentId = rootSourceIdItemList.get(0).getContentId();
                List<LongArticleCrawlerVideo> crawlerVideoList = longArticleCrawlerVideoMap.get(contentId);
                List<String> videoOssPaths = crawlerVideoList.stream().map(LongArticleCrawlerVideo::getVideoOssPath)
                        .filter(StringUtils::hasText).collect(Collectors.toList());
                List<PublishSingleVideoSource> singleVideoSources = videoPoolRepository.getByVideoOssPathIn(videoOssPaths);
                if (CollectionUtil.isNotEmpty(singleVideoSources)) {
                    isVideo = true;
                }
                if (CollectionUtil.isNotEmpty(crawlerVideoList) && crawlerVideoList.size() == 1) {
                    isSameMiniProgram = true;
                }
            }
            List<ArticleDetailInfo> detailInfoList = articleDetailInfoMap.get(article.getWxSn());
            if (CollectionUtils.isEmpty(detailInfoList)) {
                continue;
            }
            List<AccountAvgInfo> accountAvgInfoList = accountAvgInfoRepository.getAllByGhIdEqualsAndStatusEquals(article.getGhId(), 1);
            Integer fans = 0;
            if (CollectionUtils.isNotEmpty(accountAvgInfoList)) {
                fans = accountAvgInfoList.get(0).getFans();
            }
            if (isVideo) {
                if (isSameMiniProgram) {
                    if (isTest) {
                        if (article.getItemIndex() == 1) {
                            save(videoTestFirst, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(videoTestFirst, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else if (article.getItemIndex() == 2) {
                            save(videoTestSecond, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(videoTestSecond, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else {
                            save(videoTestLast, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(videoTestLast, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        }
                    } else {
                        if (article.getItemIndex() == 1) {
                            save(videoMinimumFirst, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(videoMinimumFirst, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else if (article.getItemIndex() == 2) {
                            save(videoMinimumSecond, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(videoMinimumSecond, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else {
                            save(videoMinimumLast, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(videoMinimumLast, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        }
                    }
                } else {
                    if (article.getItemIndex() == 1) {
                        save(videoBaseFirst, fans, article.getShowViewCount());
                        for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                            saveMini(videoBaseFirst, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                        }
                    } else if (article.getItemIndex() == 2) {
                        save(videoBaseSecond, fans, article.getShowViewCount());
                        for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                            saveMini(videoBaseSecond, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                        }
                    } else {
                        save(videoBaseLast, fans, article.getShowViewCount());
                        for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                            saveMini(videoBaseLast, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                        }
                    }
                }
            } else {
                if (isSameMiniProgram) {
                    if (isTest) {
                        if (article.getItemIndex() == 1) {
                            save(articleTestFirst, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(articleTestFirst, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else if (article.getItemIndex() == 2) {
                            save(articleTestSecond, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(articleTestSecond, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else {
                            save(articleTestLast, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(articleTestLast, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        }
                    } else {
                        if (article.getItemIndex() == 1) {
                            save(articleMinimumFirst, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(articleMinimumFirst, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else if (article.getItemIndex() == 2) {
                            save(articleMinimumSecond, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(articleMinimumSecond, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        } else {
                            save(articleMinimumLast, fans, article.getShowViewCount());
                            for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                                saveMini(articleMinimumLast, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                            }
                        }
                    }
                } else {
                    if (article.getItemIndex() == 1) {
                        save(articleBaseFirst, fans, article.getShowViewCount());
                        for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                            saveMini(articleBaseFirst, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                        }
                    } else if (article.getItemIndex() == 2) {
                        save(articleBaseSecond, fans, article.getShowViewCount());
                        for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                            saveMini(articleBaseSecond, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                        }
                    } else {
                        save(articleBaseLast, fans, article.getShowViewCount());
                        for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                            saveMini(articleBaseLast, articleDetailInfo.getFirstLevel(), articleDetailInfo.getFission0(), articleDetailInfo.getVideoIndex());
                        }
                    }
                }
            }
        }
        sum(articleTestSum, articleTestFirst, articleTestSecond, articleTestLast);
        sum(articleBaseSum, articleBaseFirst, articleBaseSecond, articleBaseLast);
        sum(articleMinimumSum, articleMinimumFirst, articleMinimumSecond, articleMinimumLast);
        sum(articleSum, articleTestSum, articleBaseSum, articleMinimumSum);

        sum(videoTestSum, videoTestFirst, videoTestSecond, videoTestLast);
        sum(videoBaseSum, videoBaseFirst, videoBaseSecond, videoBaseLast);
        sum(videoMinimumSum, videoMinimumFirst, videoMinimumSecond, videoMinimumLast);
        sum(videoSum, videoTestSum, videoBaseSum, videoMinimumSum);

        result.add(rate(articleTestFirst));
        result.add(rate(articleTestSecond));
        result.add(rate(articleTestLast));
        result.add(rate(articleTestSum));
        result.add(rate(articleBaseFirst));
        result.add(rate(articleBaseSecond));
        result.add(rate(articleBaseLast));
        result.add(rate(articleBaseSum));
        result.add(rate(articleMinimumFirst));
        result.add(rate(articleMinimumSecond));
        result.add(rate(articleMinimumLast));
        result.add(rate(articleMinimumSum));
        result.add(rate(articleSum));


        result.add(rate(videoTestFirst));
        result.add(rate(videoTestSecond));
        result.add(rate(videoTestLast));
        result.add(rate(videoTestSum));
        result.add(rate(videoBaseFirst));
        result.add(rate(videoBaseSecond));
        result.add(rate(videoBaseLast));
        result.add(rate(videoBaseSum));
        result.add(rate(videoMinimumFirst));
        result.add(rate(videoMinimumSecond));
        result.add(rate(videoMinimumLast));
        result.add(rate(videoMinimumSum));
        result.add(rate(videoSum));

        return result;
    }

    private List<CoverStatisticOneDataExport> buildCoverStatisticTestDataExport(String dateStr) {
        List<CoverStatisticOneDataExport> result = new ArrayList<>();
        Long start = DateUtils.getStartOfDay(dateStr, "yyyyMMdd");
        Long end = start + 86400;
        Date startDate = new Date(start * 1000);
        Date endDate = new Date(end * 1000);
        List<Article> articleList = articleRepository.getByPublishTimestampBetweenAndTypeEquals(start, end, ArticleTypeEnum.QUNFA.getVal());
        List<String> wxSnList = articleList.stream().map(Article::getWxSn).collect(Collectors.toList());
        List<ArticleDetailInfo> articleDetailInfoList = new ArrayList<>();
        for (List<String> partitions : Lists.partition(wxSnList, 1000)) {
            articleDetailInfoList.addAll(articleDetailInfoRepository.findByWxSnInAndPublishDtBetween(partitions, startDate, endDate));
        }
        List<DatastatSortStrategy> datastatSortStrategyList = datastatSortStrategyRepository.getByWxSnIn(wxSnList);
        Map<String, DatastatSortStrategy> datastatSortStrategyMap = datastatSortStrategyList.stream()
                .collect(Collectors.toMap(DatastatSortStrategy::getWxSn, Function.identity()));
        Map<String, List<ArticleDetailInfo>> articleDetailInfoMap = articleDetailInfoList.stream()
                .collect(Collectors.groupingBy(ArticleDetailInfo::getWxSn));
        // 获取rootSourceId
        Map<String, List<String>> rootSourceIdMap = new HashMap<>();
        List<String> rootSourceIdList = new ArrayList<>();
        for (Article article : articleList) {
            List<String> rootSourceIds = JSONArray.parseArray(article.getRootSourceIdList(), String.class);
            if (CollectionUtils.isEmpty(rootSourceIds)) {
                continue;
            }
            rootSourceIdMap.put(article.getWxSn(), rootSourceIds);
            rootSourceIdList.addAll(rootSourceIds);
        }
        List<LongArticlesRootSourceId> longArticlesRootSourceIdList = rootSourceIdRepository.getByRootSourceIdIn(rootSourceIdList);
        Map<String, LongArticlesRootSourceId> longArticlesRootSourceIdMap = longArticlesRootSourceIdList.stream()
                .collect(Collectors.toMap(LongArticlesRootSourceId::getRootSourceId, Function.identity()));
        // 获取视频
        List<String> contentIdList = longArticlesRootSourceIdList.stream().map(LongArticlesRootSourceId::getContentId).distinct().collect(Collectors.toList());
        List<LongArticleCrawlerVideo> longArticleCrawlerVideoList = crawlerVideoRepository.getByContentIdInAndIsIllegal(contentIdList, 0);
        Map<String, List<LongArticleCrawlerVideo>> longArticleCrawlerVideoMap = longArticleCrawlerVideoList.stream()
                .collect(Collectors.groupingBy(LongArticleCrawlerVideo::getContentId));
        for (Article article : articleList) {
            boolean isVideo = false;
            boolean isSameMiniProgram = false;
            boolean isTest = false;
            List<String> rootSourceIds = rootSourceIdMap.get(article.getWxSn());
            if (CollectionUtil.isNotEmpty(rootSourceIds)) {
                List<LongArticlesRootSourceId> rootSourceIdItemList = new ArrayList<>();
                for (String rootSourceId : rootSourceIds) {
                    LongArticlesRootSourceId longArticlesRootSourceId = longArticlesRootSourceIdMap.get(rootSourceId);
                    if (!Objects.isNull(longArticlesRootSourceId)) {
                        rootSourceIdItemList.add(longArticlesRootSourceId);
                    }
                    LongArticlesPublishMiniprogram longArticlesPublishMiniprogram
                            = longArticlesPublishMiniprogramRepository.findByRootSourceIdEquals(rootSourceId);
                    if (!Objects.isNull(longArticlesPublishMiniprogram)) {
                        if (longArticlesPublishMiniprogram.getNewVideoCoverId() != null) {
                            isTest = true;
                        }
                    }
                }
                String contentId = rootSourceIdItemList.get(0).getContentId();
                List<LongArticleCrawlerVideo> crawlerVideoList = longArticleCrawlerVideoMap.get(contentId);
                List<String> videoOssPaths = crawlerVideoList.stream().map(LongArticleCrawlerVideo::getVideoOssPath)
                        .filter(StringUtils::hasText).collect(Collectors.toList());
                List<PublishSingleVideoSource> singleVideoSources = videoPoolRepository.getByVideoOssPathIn(videoOssPaths);
                if (CollectionUtil.isNotEmpty(singleVideoSources)) {
                    isVideo = true;
                }
                if (CollectionUtil.isNotEmpty(crawlerVideoList) && crawlerVideoList.size() == 1) {
                    isSameMiniProgram = true;
                }
            }
            List<ArticleDetailInfo> detailInfoList = articleDetailInfoMap.get(article.getWxSn());
            if (CollectionUtils.isEmpty(detailInfoList)) {
                continue;
            }
            List<AccountAvgInfo> accountAvgInfoList = accountAvgInfoRepository.getAllByGhIdEqualsAndStatusEquals(article.getGhId(), 1);
            Integer fans = 0;
            if (CollectionUtils.isNotEmpty(accountAvgInfoList)) {
                fans = accountAvgInfoList.get(0).getFans();
            }
            if (isSameMiniProgram && isTest) {
                CoverStatisticOneDataExport coverStatisticOneDataExport = new CoverStatisticOneDataExport();
                if (isVideo) {
                    coverStatisticOneDataExport.setChannel("视频");
                } else {
                    coverStatisticOneDataExport.setChannel("文章");
                }
                coverStatisticOneDataExport.setDateStr(dateStr);
                coverStatisticOneDataExport.setAccountName(article.getAccountName());
                coverStatisticOneDataExport.setTitle(article.getTitle());
                coverStatisticOneDataExport.setContentUrl(article.getContentUrl());
                if (article.getItemIndex() == 1) {
                    coverStatisticOneDataExport.setIndex("头条");
                } else if (article.getItemIndex() == 2) {
                    coverStatisticOneDataExport.setIndex("次条");
                } else {
                    coverStatisticOneDataExport.setIndex("3-8条");
                }
                coverStatisticOneDataExport.setFans(fans);
                coverStatisticOneDataExport.setShowViewCount(article.getShowViewCount());
                for (ArticleDetailInfo articleDetailInfo : detailInfoList) {
                    if (articleDetailInfo.getFirstLevel() != null) {
                        coverStatisticOneDataExport.setAllFirstLevel(coverStatisticOneDataExport.getAllFirstLevel() + articleDetailInfo.getFirstLevel());
                        if (articleDetailInfo.getVideoIndex() == 1) {
                            coverStatisticOneDataExport.setOneFirstLevel(coverStatisticOneDataExport.getOneFirstLevel() + articleDetailInfo.getFirstLevel());
                        }
                        if (articleDetailInfo.getVideoIndex() == 2) {
                            coverStatisticOneDataExport.setTwoFirstLevel(coverStatisticOneDataExport.getTwoFirstLevel() + articleDetailInfo.getFirstLevel());
                        }
                    }
                    if (articleDetailInfo.getFission0() != null) {
                        coverStatisticOneDataExport.setAllFission0(coverStatisticOneDataExport.getAllFission0() + articleDetailInfo.getFission0());
                        if (articleDetailInfo.getVideoIndex() == 1) {
                            coverStatisticOneDataExport.setOneFission0(coverStatisticOneDataExport.getOneFission0() + articleDetailInfo.getFission0());
                        }
                        if (articleDetailInfo.getVideoIndex() == 2) {
                            coverStatisticOneDataExport.setTwoFission0(coverStatisticOneDataExport.getTwoFission0() + articleDetailInfo.getFission0());
                        }
                    }
                }

                if (coverStatisticOneDataExport.getShowViewCount() != 0 && coverStatisticOneDataExport.getFans() != 0) {
                    coverStatisticOneDataExport.setShowViewRate((double) coverStatisticOneDataExport.getShowViewCount() / coverStatisticOneDataExport.getFans());
                }
                if (coverStatisticOneDataExport.getShowViewCount() != 0) {
                    if (coverStatisticOneDataExport.getAllFirstLevel() != 0) {
                        coverStatisticOneDataExport.setAllFirstLevelRate((double) coverStatisticOneDataExport.getAllFirstLevel() / coverStatisticOneDataExport.getShowViewCount());
                    }
                    if (coverStatisticOneDataExport.getOneFirstLevel() != 0) {
                        coverStatisticOneDataExport.setOneFirstLevelRate((double) coverStatisticOneDataExport.getOneFirstLevel() / coverStatisticOneDataExport.getShowViewCount());
                    }
                    if (coverStatisticOneDataExport.getTwoFirstLevel() != 0) {
                        coverStatisticOneDataExport.setTwoFirstLevelRate((double) coverStatisticOneDataExport.getTwoFirstLevel() / coverStatisticOneDataExport.getShowViewCount());
                    }
                }

                if (coverStatisticOneDataExport.getAllFirstLevel() != 0 && coverStatisticOneDataExport.getAllFission0() != 0) {
                    coverStatisticOneDataExport.setAllFission0Rate((double) coverStatisticOneDataExport.getAllFission0() / coverStatisticOneDataExport.getAllFirstLevel());
                }
                if (coverStatisticOneDataExport.getOneFirstLevel() != 0 && coverStatisticOneDataExport.getOneFission0() != 0) {
                    coverStatisticOneDataExport.setOneFission0Rate((double) coverStatisticOneDataExport.getOneFission0() / coverStatisticOneDataExport.getOneFirstLevel());
                }
                if (coverStatisticOneDataExport.getTwoFirstLevel() != 0 && coverStatisticOneDataExport.getTwoFission0() != 0) {
                    coverStatisticOneDataExport.setTwoFission0Rate((double) coverStatisticOneDataExport.getTwoFission0() / coverStatisticOneDataExport.getTwoFirstLevel());
                }
                result.add(coverStatisticOneDataExport);
            }
        }
        if (!CollectionUtils.isEmpty(result)) {
            result = result.stream().sorted(Comparator.comparing(CoverStatisticOneDataExport::getChannel)).collect(Collectors.toList());
        }
        return result;
    }

    private void save(CoverStatisticDataExport coverStatisticDataExport, Integer fans, Integer showViewCount) {
        if (fans != null) {
            coverStatisticDataExport.setFans(coverStatisticDataExport.getFans() + fans);
        }
        if (showViewCount != null) {
            coverStatisticDataExport.setShowViewCount(coverStatisticDataExport.getShowViewCount() + showViewCount);
        }
        coverStatisticDataExport.setPublishCount(coverStatisticDataExport.getPublishCount() + 1);
    }

    private void saveMini(CoverStatisticDataExport coverStatisticDataExport, Integer firstLevel, Integer fission0, Integer index) {
        if (firstLevel != null) {
            coverStatisticDataExport.setAllFirstLevel(coverStatisticDataExport.getAllFirstLevel() + firstLevel);
            if (index == 1) {
                coverStatisticDataExport.setOneFirstLevel(coverStatisticDataExport.getOneFirstLevel() + firstLevel);
            }
            if (index == 2) {
                coverStatisticDataExport.setTwoFirstLevel(coverStatisticDataExport.getTwoFirstLevel() + firstLevel);
            }
        }
        if (fission0 != null) {
            coverStatisticDataExport.setAllFission0(coverStatisticDataExport.getAllFission0() + fission0);
            if (index == 1) {
                coverStatisticDataExport.setOneFission0(coverStatisticDataExport.getOneFission0() + fission0);
            }
            if (index == 2) {
                coverStatisticDataExport.setTwoFission0(coverStatisticDataExport.getTwoFission0() + fission0);
            }
        }
    }

    private void sum(CoverStatisticDataExport sumCoverStatisticDataExport,
                     CoverStatisticDataExport coverStatisticDataExport1,
                     CoverStatisticDataExport coverStatisticDataExport2,
                     CoverStatisticDataExport coverStatisticDataExport3) {
        sumCoverStatisticDataExport.setFans(coverStatisticDataExport1.getFans() + coverStatisticDataExport2.getFans() + coverStatisticDataExport3.getFans());
        sumCoverStatisticDataExport.setPublishCount(coverStatisticDataExport1.getPublishCount() + coverStatisticDataExport2.getPublishCount() + coverStatisticDataExport3.getPublishCount());
        sumCoverStatisticDataExport.setShowViewCount(coverStatisticDataExport1.getShowViewCount() + coverStatisticDataExport2.getShowViewCount() + coverStatisticDataExport3.getShowViewCount());
        sumCoverStatisticDataExport.setAllFirstLevel(coverStatisticDataExport1.getAllFirstLevel() + coverStatisticDataExport2.getAllFirstLevel() + coverStatisticDataExport3.getAllFirstLevel());
        sumCoverStatisticDataExport.setOneFirstLevel(coverStatisticDataExport1.getOneFirstLevel() + coverStatisticDataExport2.getOneFirstLevel() + coverStatisticDataExport3.getOneFirstLevel());
        sumCoverStatisticDataExport.setTwoFirstLevel(coverStatisticDataExport1.getTwoFirstLevel() + coverStatisticDataExport2.getTwoFirstLevel() + coverStatisticDataExport3.getTwoFirstLevel());
        sumCoverStatisticDataExport.setAllFission0(coverStatisticDataExport1.getAllFission0() + coverStatisticDataExport2.getAllFission0() + coverStatisticDataExport3.getAllFission0());
        sumCoverStatisticDataExport.setOneFission0(coverStatisticDataExport1.getOneFission0() + coverStatisticDataExport2.getOneFission0() + coverStatisticDataExport3.getOneFission0());
        sumCoverStatisticDataExport.setTwoFission0(coverStatisticDataExport1.getTwoFission0() + coverStatisticDataExport2.getTwoFission0() + coverStatisticDataExport3.getTwoFission0());
    }

    private CoverStatisticDataExport rate(CoverStatisticDataExport coverStatisticDataExport) {
        if (coverStatisticDataExport.getShowViewCount() != 0 && coverStatisticDataExport.getFans() != 0) {
            coverStatisticDataExport.setShowViewRate((double) coverStatisticDataExport.getShowViewCount() / coverStatisticDataExport.getFans());
        }
        if (coverStatisticDataExport.getShowViewCount() != 0) {
            if (coverStatisticDataExport.getAllFirstLevel() != 0) {
                coverStatisticDataExport.setAllFirstLevelRate((double) coverStatisticDataExport.getAllFirstLevel() / coverStatisticDataExport.getShowViewCount());
            }
            if (coverStatisticDataExport.getOneFirstLevel() != 0) {
                coverStatisticDataExport.setOneFirstLevelRate((double) coverStatisticDataExport.getOneFirstLevel() / coverStatisticDataExport.getShowViewCount());
            }
            if (coverStatisticDataExport.getTwoFirstLevel() != 0) {
                coverStatisticDataExport.setTwoFirstLevelRate((double) coverStatisticDataExport.getTwoFirstLevel() / coverStatisticDataExport.getShowViewCount());
            }
        }

        if (coverStatisticDataExport.getAllFirstLevel() != 0 && coverStatisticDataExport.getAllFission0() != 0) {
            coverStatisticDataExport.setAllFission0Rate((double) coverStatisticDataExport.getAllFission0() / coverStatisticDataExport.getAllFirstLevel());
        }
        if (coverStatisticDataExport.getOneFirstLevel() != 0 && coverStatisticDataExport.getOneFission0() != 0) {
            coverStatisticDataExport.setOneFission0Rate((double) coverStatisticDataExport.getOneFission0() / coverStatisticDataExport.getOneFirstLevel());
        }
        if (coverStatisticDataExport.getTwoFirstLevel() != 0 && coverStatisticDataExport.getTwoFission0() != 0) {
            coverStatisticDataExport.setTwoFission0Rate((double) coverStatisticDataExport.getTwoFission0() / coverStatisticDataExport.getTwoFirstLevel());
        }
        return coverStatisticDataExport;
    }


    @XxlJob("dailyAuditProduceExport")
    public ReturnT<String> dailyAuditProduceJob(String param) {
        List<String> dateStrList = DateUtils.getBeforeDays(null, null, 1);
        contentEffectGroupBySource(dateStrList);
        return ReturnT.SUCCESS;
    }

    public void dailyAuditProduce(String dateStr) {
        if (!StringUtils.hasText(dateStr)) {
            dateStr = DateUtils.getBeforeDaysDateStr("yyyyMMdd", 1);
        }
        dailyAuditProduce(Collections.singletonList(dateStr));
    }

    public void dailyAuditProduce(List<String> dateStrList) {
        List<DailyAuditProduceExport> exportList = new ArrayList<>();
        dateStrList = Lists.reverse(dateStrList);
        for (String dateStr : dateStrList) {
            exportList.addAll(buildDailyAuditProduceExport(dateStr));
        }
        if (CollectionUtil.isEmpty(exportList)) {
            return;
        }
        int rowNum = exportList.size();
        List<List<Object>> rows = new ArrayList<>();
        Field[] fields = DailyAuditProduceExport.class.getDeclaredFields();
        for (DailyAuditProduceExport datum : exportList) {
            List<Object> rowDatas = new ArrayList<>();
            rows.add(rowDatas);

            for (Field field : fields) {
                field.setAccessible(true);
                try {
                    rowDatas.add(field.get(datum));
                } catch (IllegalAccessException e) {
                    log.error("获取值出错：{}", field.getName());
                } catch (Exception e) {
                    throw new RuntimeException(e.getMessage());
                }
            }
        }

        List<Pair<String, String>> styles = Arrays
                .asList(
                        Pair.of("F", "0.00%"),
                        Pair.of("I", "0.00%")
                );
        List<Pair<String, List<Pair<String, String>>>> thank = Arrays
                .asList(
                        Pair.of("B", Arrays.asList(
                                Pair.of("长文审核", "#BACEFD"),
                                Pair.of("文章内容池", "#FED4A4")))
                );
        doSendFeishuSheet(dateStrList, dailyDetailSheetToken, "Lushkl", rowNum, rows,
                3, styles, null, thank);
    }

    private List<DailyAuditProduceExport> buildDailyAuditProduceExport(String dateStr) {
        Long startTimeStamp = DateUtils.getStartOfDay(dateStr, "yyyyMMdd") * 1000;
        Long endTimeStamp = startTimeStamp + 86400000;
        List<DailyAuditProduceExport> result = new ArrayList<>();
        List<DailyAuditProduceExport> produceAuditList = aigcBaseMapper.getAccountDailyProduceAuditCount(startTimeStamp, endTimeStamp);
        List<DailyAuditProduceExport> videoAuditList = longArticleBaseMapper.getAccountDailyVideoAuditCount(startTimeStamp, endTimeStamp);
        for (DailyAuditProduceExport dailyAuditProduceExport : produceAuditList) {
            dailyAuditProduceExport.setType("长文审核");
            result.add(dailyAuditProduceExport);
        }
        for (DailyAuditProduceExport dailyAuditProduceExport : videoAuditList) {
            dailyAuditProduceExport.setType("文章内容池");
            result.add(dailyAuditProduceExport);
        }
        for (DailyAuditProduceExport item : result) {
            item.setDateStr(dateStr);
            if (item.getAuditCount()!= null && item.getAuditCount()!= 0) {
                item.setAuditPassRate((double) item.getAuditPassCount() / item.getAuditCount());
            }
            if (item.getVideoAuditCount()!= null && item.getVideoAuditCount()!= 0) {
                item.setVideoAuditPassRate((double) item.getVideoAuditPassCount() / item.getVideoAuditCount());
            }
        }
        return result;
    }


}
